class DefinitionBase(FrameworkContentElement,IInputElement,IAnimatable,IFrameworkInputElement,ISupportInitialize,IQueryAmbient):
 """ Defines the functionality required to support a shared-size group that is used by the System.Windows.Controls.ColumnDefinitionCollection and System.Windows.Controls.RowDefinitionCollection classes. This is an abstract class. """
 def AddLogicalChild(self,*args):
  """
  AddLogicalChild(self: FrameworkContentElement,child: object)

   Adds the provided element as a child of this element.

  

   child: The child element to be added.
  """
  pass
 def GetUIParentCore(self,*args):
  """
  GetUIParentCore(self: FrameworkContentElement) -> DependencyObject

  

   Returns an alternative logical parent for this element if there is no visual parent. In this 

    case,a System.Windows.FrameworkContentElement  parent is always the same value as the 

    System.Windows.FrameworkContentElement.Parent property.

  

   Returns: Returns something other than null whenever a WPF framework-level implementation of this method 

    has a non-visual parent connection.
  """
  pass
 def OnContextMenuClosing(self,*args):
  """
  OnContextMenuClosing(self: FrameworkContentElement,e: ContextMenuEventArgs)

   Invoked whenever the System.Windows.FrameworkContentElement.ContextMenuClosing routed event 

    reaches this class in its route. Implement this method to add class handling for this event.

  

  

   e: Provides data about the event.
  """
  pass
 def OnContextMenuOpening(self,*args):
  """
  OnContextMenuOpening(self: FrameworkContentElement,e: ContextMenuEventArgs)

   Invoked whenever the System.Windows.FrameworkContentElement.ContextMenuOpening routed event 

    reaches this class in its route. Implement this method to add class handling for this event.

  

  

   e: Event data for the event.
  """
  pass
 def OnCreateAutomationPeer(self,*args):
  """
  OnCreateAutomationPeer(self: ContentElement) -> AutomationPeer

  

   Returns class-specific System.Windows.Automation.Peers.AutomationPeer implementations for the 

    Windows Presentation Foundation (WPF) infrastructure.

  

   Returns: The type-specific System.Windows.Automation.Peers.AutomationPeer implementation.
  """
  pass
 def OnDragEnter(self,*args):
  """
  OnDragEnter(self: ContentElement,e: DragEventArgs)

   Invoked when an unhandled System.Windows.DragDrop.DragEnter�attached event reaches an element in 

    its route that is derived from this class. Implement this method to add class handling for this 

    event.

  

  

   e: The System.Windows.DragEventArgs that contains the event data.
  """
  pass
 def OnDragLeave(self,*args):
  """
  OnDragLeave(self: ContentElement,e: DragEventArgs)

   Invoked when an unhandled System.Windows.DragDrop.DragLeave�attached event reaches an element in 

    its route that is derived from this class. Implement this method to add class handling for this 

    event.

  

  

   e: The System.Windows.DragEventArgs that contains the event data.
  """
  pass
 def OnDragOver(self,*args):
  """
  OnDragOver(self: ContentElement,e: DragEventArgs)

   Invoked when an unhandled System.Windows.DragDrop.DragOver�attached event reaches an element in 

    its route that is derived from this class. Implement this method to add class handling for this 

    event.

  

  

   e: The System.Windows.DragEventArgs that contains the event data.
  """
  pass
 def OnDrop(self,*args):
  """
  OnDrop(self: ContentElement,e: DragEventArgs)

   Invoked when an unhandled System.Windows.DragDrop.DragEnter�attached event reaches an element in 

    its route that is derived from this class. Implement this method to add class handling for this 

    event.

  

  

   e: The System.Windows.DragEventArgs that contains the event data.
  """
  pass
 def OnGiveFeedback(self,*args):
  """
  OnGiveFeedback(self: ContentElement,e: GiveFeedbackEventArgs)

   Invoked when an unhandled System.Windows.DragDrop.GiveFeedback�attached event reaches an element 

    in its route that is derived from this class. Implement this method to add class handling for 

    this event.

  

  

   e: The System.Windows.GiveFeedbackEventArgs that contains the event data.
  """
  pass
 def OnGotFocus(self,*args):
  """
  OnGotFocus(self: FrameworkContentElement,e: RoutedEventArgs)

   Class handler for the System.Windows.ContentElement.GotFocus event.

  

   e: Event data for the event.
  """
  pass
 def OnGotKeyboardFocus(self,*args):
  """
  OnGotKeyboardFocus(self: ContentElement,e: KeyboardFocusChangedEventArgs)

   Invoked when an unhandled System.Windows.Input.Keyboard.GotKeyboardFocus�attached event reaches 

    an element in its route that is derived from this class. Implement this method to add class 

    handling for this event.

  

  

   e: The System.Windows.Input.KeyboardFocusChangedEventArgs that contains the event data.
  """
  pass
 def OnGotMouseCapture(self,*args):
  """
  OnGotMouseCapture(self: ContentElement,e: MouseEventArgs)

   Invoked when an unhandled System.Windows.Input.Mouse.GotMouseCapture�attached event reaches an 

    element in its route that is derived from this class. Implement this method to add class 

    handling for this event.

  

  

   e: The System.Windows.Input.MouseEventArgs that contains the event data.
  """
  pass
 def OnGotStylusCapture(self,*args):
  """
  OnGotStylusCapture(self: ContentElement,e: StylusEventArgs)

   Invoked when an unhandled System.Windows.Input.Stylus.GotStylusCapture�attached event reaches an 

    element in its route that is derived from this class. Implement this method to add class 

    handling for this event.

  

  

   e: The System.Windows.Input.StylusEventArgs that contains the event data.
  """
  pass
 def OnGotTouchCapture(self,*args):
  """
  OnGotTouchCapture(self: ContentElement,e: TouchEventArgs)

   Provides class handling for the System.Windows.ContentElement.GotTouchCapture routed event that 

    occurs when a touch is captured to this element.

  

  

   e: A System.Windows.Input.TouchEventArgs that contains the event data.
  """
  pass
 def OnInitialized(self,*args):
  """
  OnInitialized(self: FrameworkContentElement,e: EventArgs)

   Raises the System.Windows.FrameworkContentElement.Initialized event. This method is invoked 

    whenever System.Windows.FrameworkContentElement.IsInitialized is set to true.

  

  

   e: Event data for the event.
  """
  pass
 def OnIsKeyboardFocusedChanged(self,*args):
  """
  OnIsKeyboardFocusedChanged(self: ContentElement,e: DependencyPropertyChangedEventArgs)

   Invoked when an unhandled System.Windows.ContentElement.IsKeyboardFocusedChanged event is raised 

    on this element. Implement this method to add class handling for this event.

  

  

   e: The System.Windows.DependencyPropertyChangedEventArgs that contains the event data.
  """
  pass
 def OnIsKeyboardFocusWithinChanged(self,*args):
  """
  OnIsKeyboardFocusWithinChanged(self: ContentElement,e: DependencyPropertyChangedEventArgs)

   Invoked just before the System.Windows.ContentElement.IsKeyboardFocusWithinChanged event is 

    raised by this element. Implement this method to add class handling for this event.

  

  

   e: A System.Windows.DependencyPropertyChangedEventArgs that contains the event data.
  """
  pass
 def OnIsMouseCapturedChanged(self,*args):
  """
  OnIsMouseCapturedChanged(self: ContentElement,e: DependencyPropertyChangedEventArgs)

   Invoked when an unhandled System.Windows.ContentElement.IsMouseCapturedChanged event is raised 

    on this element. Implement this method to add class handling for this event.

  

  

   e: The System.Windows.DependencyPropertyChangedEventArgs that contains the event data.
  """
  pass
 def OnIsMouseCaptureWithinChanged(self,*args):
  """
  OnIsMouseCaptureWithinChanged(self: ContentElement,e: DependencyPropertyChangedEventArgs)

   Invoked when an unhandled System.Windows.ContentElement.IsMouseCaptureWithinChanged event is 

    raised on this element. Implement this method to add class handling for this event.

  

  

   e: A System.Windows.DependencyPropertyChangedEventArgs that contains the event data.
  """
  pass
 def OnIsMouseDirectlyOverChanged(self,*args):
  """
  OnIsMouseDirectlyOverChanged(self: ContentElement,e: DependencyPropertyChangedEventArgs)

   Invoked when an unhandled System.Windows.ContentElement.IsMouseDirectlyOverChanged event is 

    raised on this element. Implement this method to add class handling for this event.

  

  

   e: The System.Windows.DependencyPropertyChangedEventArgs that contains the event data.
  """
  pass
 def OnIsStylusCapturedChanged(self,*args):
  """
  OnIsStylusCapturedChanged(self: ContentElement,e: DependencyPropertyChangedEventArgs)

   Invoked when an unhandled System.Windows.ContentElement.IsStylusCapturedChanged event is raised 

    on this element. Implement this method to add class handling for this event.

  

  

   e: A System.Windows.DependencyPropertyChangedEventArgs that contains the event data.
  """
  pass
 def OnIsStylusCaptureWithinChanged(self,*args):
  """
  OnIsStylusCaptureWithinChanged(self: ContentElement,e: DependencyPropertyChangedEventArgs)

   Invoked when an unhandled System.Windows.ContentElement.IsStylusCaptureWithinChanged event is 

    raised on this element. Implement this method to add class handling for this event.

  

  

   e: The System.Windows.DependencyPropertyChangedEventArgs that contains the event data.
  """
  pass
 def OnIsStylusDirectlyOverChanged(self,*args):
  """
  OnIsStylusDirectlyOverChanged(self: ContentElement,e: DependencyPropertyChangedEventArgs)

   Invoked when an unhandled System.Windows.ContentElement.IsStylusDirectlyOverChanged event is 

    raised on this element. Implement this method to add class handling for this event.

  

  

   e: The System.Windows.DependencyPropertyChangedEventArgs that contains the event data.
  """
  pass
 def OnKeyDown(self,*args):
  """
  OnKeyDown(self: ContentElement,e: KeyEventArgs)

   Invoked when an unhandled System.Windows.Input.Keyboard.KeyDown�attached event reaches an 

    element in its route that is derived from this class. Implement this method to add class 

    handling for this event.

  

  

   e: The System.Windows.Input.KeyEventArgs that contains the event data.
  """
  pass
 def OnKeyUp(self,*args):
  """
  OnKeyUp(self: ContentElement,e: KeyEventArgs)

   Invoked when an unhandled System.Windows.Input.Keyboard.KeyUp�attached event reaches an element 

    in its route that is derived from this class. Implement this method to add class handling for 

    this event.

  

  

   e: The System.Windows.Input.KeyEventArgs that contains the event data.
  """
  pass
 def OnLostFocus(self,*args):
  """
  OnLostFocus(self: ContentElement,e: RoutedEventArgs)

   Raises the System.Windows.ContentElement.LostFocus�routed event by using the event data that is 

    provided.

  

  

   e: A System.Windows.RoutedEventArgs that contains event data. This event data must contain the 

    identifier for the System.Windows.ContentElement.LostFocus event.
  """
  pass
 def OnLostKeyboardFocus(self,*args):
  """
  OnLostKeyboardFocus(self: ContentElement,e: KeyboardFocusChangedEventArgs)

   Invoked when an unhandled System.Windows.Input.Keyboard.LostKeyboardFocus�attached event reaches 

    an element in its route that is derived from this class. Implement this method to add class 

    handling for this event.

  

  

   e: The System.Windows.Input.KeyboardFocusChangedEventArgs that contains event data.
  """
  pass
 def OnLostMouseCapture(self,*args):
  """
  OnLostMouseCapture(self: ContentElement,e: MouseEventArgs)

   Invoked when an unhandled System.Windows.Input.Mouse.LostMouseCapture�attached event reaches an 

    element in its route that is derived from this class. Implement this method to add class 

    handling for this event.

  

  

   e: The System.Windows.Input.MouseEventArgs that contains event data.
  """
  pass
 def OnLostStylusCapture(self,*args):
  """
  OnLostStylusCapture(self: ContentElement,e: StylusEventArgs)

   Invoked when an unhandled System.Windows.Input.Stylus.LostStylusCapture�attached event reaches 

    an element in its route that is derived from this class. Implement this method to add class 

    handling for this event.

  

  

   e: The System.Windows.Input.StylusEventArgs that contains event data.
  """
  pass
 def OnLostTouchCapture(self,*args):
  """
  OnLostTouchCapture(self: ContentElement,e: TouchEventArgs)

   Provides class handling for the System.Windows.ContentElement.LostTouchCapture routed event that 

    occurs when this element loses a touch capture.

  

  

   e: A System.Windows.Input.TouchEventArgs that contains the event data.
  """
  pass
 def OnMouseDown(self,*args):
  """
  OnMouseDown(self: ContentElement,e: MouseButtonEventArgs)

   Invoked when an unhandled System.Windows.Input.Mouse.MouseDown�attached event reaches an element 

    in its route that is derived from this class. Implement this method to add class handling for 

    this event.

  

  

   e: The System.Windows.Input.MouseButtonEventArgs that contains the event data. This event data 

    reports details about the mouse button that was pressed and the handled state.
  """
  pass
 def OnMouseEnter(self,*args):
  """
  OnMouseEnter(self: ContentElement,e: MouseEventArgs)

   Invoked when an unhandled System.Windows.Input.Mouse.MouseEnter�attached event is raised on this 

    element. Implement this method to add class handling for this event.

  

  

   e: The System.Windows.Input.MouseEventArgs that contains the event data.
  """
  pass
 def OnMouseLeave(self,*args):
  """
  OnMouseLeave(self: ContentElement,e: MouseEventArgs)

   Invoked when an unhandled System.Windows.Input.Mouse.MouseLeave�attached event is raised on this 

    element. Implement this method to add class handling for this event.

  

  

   e: The System.Windows.Input.MouseEventArgs that contains the event data.
  """
  pass
 def OnMouseLeftButtonDown(self,*args):
  """
  OnMouseLeftButtonDown(self: ContentElement,e: MouseButtonEventArgs)

   Invoked when an unhandled System.Windows.ContentElement.MouseLeftButtonDown�routed event is 

    raised on this element. Implement this method to add class handling for this event.

  

  

   e: The System.Windows.Input.MouseButtonEventArgs that contains the event data. The event data 

    reports that the left mouse button was pressed.
  """
  pass
 def OnMouseLeftButtonUp(self,*args):
  """
  OnMouseLeftButtonUp(self: ContentElement,e: MouseButtonEventArgs)

   Invoked when an unhandled System.Windows.ContentElement.MouseLeftButtonUp�routed event reaches 

    an element in its route that is derived from this class. Implement this method to add class 

    handling for this event.

  

  

   e: The System.Windows.Input.MouseButtonEventArgs that contains the event data. The event data 

    reports that the left mouse button was released.
  """
  pass
 def OnMouseMove(self,*args):
  """
  OnMouseMove(self: ContentElement,e: MouseEventArgs)

   Invoked when an unhandled System.Windows.Input.Mouse.MouseMove�attached event reaches an element 

    in its route that is derived from this class. Implement this method to add class handling for 

    this event.

  

  

   e: The System.Windows.Input.MouseEventArgs that contains the event data.
  """
  pass
 def OnMouseRightButtonDown(self,*args):
  """
  OnMouseRightButtonDown(self: ContentElement,e: MouseButtonEventArgs)

   Invoked when an unhandled System.Windows.ContentElement.MouseRightButtonDown�routed event 

    reaches an element in its route that is derived from this class. Implement this method to add 

    class handling for this event.

  

  

   e: The System.Windows.Input.MouseButtonEventArgs that contains the event data. The event data 

    reports that the right mouse button was pressed.
  """
  pass
 def OnMouseRightButtonUp(self,*args):
  """
  OnMouseRightButtonUp(self: ContentElement,e: MouseButtonEventArgs)

   Invoked when an unhandled System.Windows.ContentElement.MouseRightButtonUp�routed event reaches 

    an element in its route that is derived from this class. Implement this method to add class 

    handling for this event.

  

  

   e: The System.Windows.Input.MouseButtonEventArgs that contains the event data. The event data 

    reports that the right mouse button was released.
  """
  pass
 def OnMouseUp(self,*args):
  """
  OnMouseUp(self: ContentElement,e: MouseButtonEventArgs)

   Invoked when an unhandled System.Windows.Input.Mouse.MouseUp�routed event reaches an element in 

    its route that is derived from this class. Implement this method to add class handling for this 

    event.

  

  

   e: The System.Windows.Input.MouseButtonEventArgs that contains the event data. The event data 

    reports that the mouse button was released.
  """
  pass
 def OnMouseWheel(self,*args):
  """
  OnMouseWheel(self: ContentElement,e: MouseWheelEventArgs)

   Invoked when an unhandled System.Windows.Input.Mouse.MouseWheel�attached event reaches an 

    element in its route that is derived from this class. Implement this method to add class 

    handling for this event.

  

  

   e: The System.Windows.Input.MouseWheelEventArgs that contains the event data.
  """
  pass
 def OnPreviewDragEnter(self,*args):
  """
  OnPreviewDragEnter(self: ContentElement,e: DragEventArgs)

   Invoked when an unhandled System.Windows.DragDrop.PreviewDragEnter�attached event reaches an 

    element in its route that is derived from this class. Implement this method to add class 

    handling for this event.

  

  

   e: The System.Windows.DragEventArgs that contains the event data.
  """
  pass
 def OnPreviewDragLeave(self,*args):
  """
  OnPreviewDragLeave(self: ContentElement,e: DragEventArgs)

   Invoked when an unhandled System.Windows.DragDrop.PreviewDragLeave�attached event reaches an 

    element in its route that is derived from this class. Implement this method to add class 

    handling for this event.

  

  

   e: The System.Windows.DragEventArgs that contains the event data.
  """
  pass
 def OnPreviewDragOver(self,*args):
  """
  OnPreviewDragOver(self: ContentElement,e: DragEventArgs)

   Invoked when an unhandled System.Windows.DragDrop.PreviewDragOver�attached event reaches an 

    element in its route that is derived from this class. Implement this method to add class 

    handling for this event.

  

  

   e: The System.Windows.DragEventArgs that contains the event data.
  """
  pass
 def OnPreviewDrop(self,*args):
  """
  OnPreviewDrop(self: ContentElement,e: DragEventArgs)

   Invoked when an unhandled System.Windows.DragDrop.PreviewDrop�attached event reaches an element 

    in its route that is derived from this class. Implement this method to add class handling for 

    this event.

  

  

   e: The System.Windows.DragEventArgs that contains the event data.
  """
  pass
 def OnPreviewGiveFeedback(self,*args):
  """
  OnPreviewGiveFeedback(self: ContentElement,e: GiveFeedbackEventArgs)

   Invoked when an unhandled System.Windows.DragDrop.PreviewGiveFeedback�attached event reaches an 

    element in its route that is derived from this class. Implement this method to add class 

    handling for this event.

  

  

   e: The System.Windows.GiveFeedbackEventArgs that contains the event data.
  """
  pass
 def OnPreviewGotKeyboardFocus(self,*args):
  """
  OnPreviewGotKeyboardFocus(self: ContentElement,e: KeyboardFocusChangedEventArgs)

   Invoked when an unhandled System.Windows.Input.Keyboard.PreviewGotKeyboardFocus�attached event 

    reaches an element in its route that is derived from this class. Implement this method to add 

    class handling for this event.

  

  

   e: The System.Windows.Input.KeyboardFocusChangedEventArgs that contains the event data.
  """
  pass
 def OnPreviewKeyDown(self,*args):
  """
  OnPreviewKeyDown(self: ContentElement,e: KeyEventArgs)

   Invoked when an unhandled System.Windows.Input.Keyboard.PreviewKeyDown�attached event reaches an 

    element in its route that is derived from this class. Implement this method to add class 

    handling for this event.

  

  

   e: The System.Windows.Input.KeyEventArgs that contains the event data.
  """
  pass
 def OnPreviewKeyUp(self,*args):
  """
  OnPreviewKeyUp(self: ContentElement,e: KeyEventArgs)

   Invoked when an unhandled System.Windows.Input.Keyboard.PreviewKeyUp�attached event reaches an 

    element in its route that is derived from this class. Implement this method to add class 

    handling for this event.

  

  

   e: The System.Windows.Input.KeyEventArgs that contains the event data.
  """
  pass
 def OnPreviewLostKeyboardFocus(self,*args):
  """
  OnPreviewLostKeyboardFocus(self: ContentElement,e: KeyboardFocusChangedEventArgs)

   Invoked when an unhandled System.Windows.Input.Keyboard.PreviewKeyDown�attached event reaches an 

    element in its route that is derived from this class. Implement this method to add class 

    handling for this event.

  

  

   e: The System.Windows.Input.KeyboardFocusChangedEventArgs that contains the event data.
  """
  pass
 def OnPreviewMouseDown(self,*args):
  """
  OnPreviewMouseDown(self: ContentElement,e: MouseButtonEventArgs)

   Invoked when an unhandled System.Windows.Input.Mouse.PreviewMouseDown attached�routed event 

    reaches an element in its route that is derived from this class. Implement this method to add 

    class handling for this event.

  

  

   e: The System.Windows.Input.MouseButtonEventArgs that contains the event data. The event data 

    reports that one or more mouse buttons were pressed.
  """
  pass
 def OnPreviewMouseLeftButtonDown(self,*args):
  """
  OnPreviewMouseLeftButtonDown(self: ContentElement,e: MouseButtonEventArgs)

   Invoked when an unhandled System.Windows.ContentElement.PreviewMouseLeftButtonDown�routed event 

    reaches an element in its route that is derived from this class. Implement this method to add 

    class handling for this event.

  

  

   e: The System.Windows.Input.MouseButtonEventArgs that contains the event data. The event data 

    reports that the left mouse button was pressed.
  """
  pass
 def OnPreviewMouseLeftButtonUp(self,*args):
  """
  OnPreviewMouseLeftButtonUp(self: ContentElement,e: MouseButtonEventArgs)

   Invoked when an unhandled System.Windows.ContentElement.PreviewMouseLeftButtonUp�routed event 

    reaches an element in its route that is derived from this class. Implement this method to add 

    class handling for this event.

  

  

   e: The System.Windows.Input.MouseButtonEventArgs that contains the event data. The event data 

    reports that the left mouse button was released.
  """
  pass
 def OnPreviewMouseMove(self,*args):
  """
  OnPreviewMouseMove(self: ContentElement,e: MouseEventArgs)

   Invoked when an unhandled System.Windows.Input.Mouse.PreviewMouseMove�attached event reaches an 

    element in its route that is derived from this class. Implement this method to add class 

    handling for this event.

  

  

   e: The System.Windows.Input.MouseEventArgs that contains the event data.
  """
  pass
 def OnPreviewMouseRightButtonDown(self,*args):
  """
  OnPreviewMouseRightButtonDown(self: ContentElement,e: MouseButtonEventArgs)

   Invoked when an unhandled System.Windows.ContentElement.PreviewMouseRightButtonDown�routed event 

    reaches an element in its route that is derived from this class. Implement this method to add 

    class handling for this event.

  

  

   e: The System.Windows.Input.MouseButtonEventArgs that contains the event data. The event data 

    reports that the right mouse button was pressed.
  """
  pass
 def OnPreviewMouseRightButtonUp(self,*args):
  """
  OnPreviewMouseRightButtonUp(self: ContentElement,e: MouseButtonEventArgs)

   Invoked when an unhandled System.Windows.ContentElement.PreviewMouseRightButtonUp�routed event 

    reaches an element in its route that is derived from this class. Implement this method to add 

    class handling for this event.

  

  

   e: The System.Windows.Input.MouseButtonEventArgs that contains the event data. The event data 

    reports that the right mouse button was released.
  """
  pass
 def OnPreviewMouseUp(self,*args):
  """
  OnPreviewMouseUp(self: ContentElement,e: MouseButtonEventArgs)

   Invoked when an unhandled System.Windows.Input.Mouse.PreviewMouseUp�attached event reaches an 

    element in its route that is derived from this class. Implement this method to add class 

    handling for this event.

  

  

   e: The System.Windows.Input.MouseButtonEventArgs that contains the event data. The event data 

    reports that one or more mouse buttons were released.
  """
  pass
 def OnPreviewMouseWheel(self,*args):
  """
  OnPreviewMouseWheel(self: ContentElement,e: MouseWheelEventArgs)

   Invoked when an unhandled System.Windows.Input.Mouse.PreviewMouseWheel�attached event reaches an 

    element in its route that is derived from this class. Implement this method to add class 

    handling for this event.

  

  

   e: The System.Windows.Input.MouseWheelEventArgs that contains the event data.
  """
  pass
 def OnPreviewQueryContinueDrag(self,*args):
  """
  OnPreviewQueryContinueDrag(self: ContentElement,e: QueryContinueDragEventArgs)

   Invoked when an unhandled System.Windows.DragDrop.PreviewQueryContinueDrag�attached event 

    reaches an element in its route that is derived from this class. Implement this method to add 

    class handling for this event.

  

  

   e: The System.Windows.QueryContinueDragEventArgs that contains the event data.
  """
  pass
 def OnPreviewStylusButtonDown(self,*args):
  """
  OnPreviewStylusButtonDown(self: ContentElement,e: StylusButtonEventArgs)

   Invoked when an unhandled System.Windows.Input.Stylus.PreviewStylusButtonDown�attached event 

    reaches an element in its route that is derived from this class. Implement this method to add 

    class handling for this event.

  

  

   e: The System.Windows.Input.StylusButtonEventArgs that contains the event data.
  """
  pass
 def OnPreviewStylusButtonUp(self,*args):
  """
  OnPreviewStylusButtonUp(self: ContentElement,e: StylusButtonEventArgs)

   Invoked when an unhandled System.Windows.Input.Stylus.PreviewStylusButtonUp�attached event 

    reaches an element in its route that is derived from this class. Implement this method to add 

    class handling for this event.

  

  

   e: The System.Windows.Input.StylusButtonEventArgs that contains the event data.
  """
  pass
 def OnPreviewStylusDown(self,*args):
  """
  OnPreviewStylusDown(self: ContentElement,e: StylusDownEventArgs)

   Invoked when an unhandled System.Windows.Input.Stylus.PreviewStylusDown�attached event reaches 

    an element in its route that is derived from this class. Implement this method to add class 

    handling for this event.

  

  

   e: The System.Windows.Input.StylusDownEventArgs that contains the event data.
  """
  pass
 def OnPreviewStylusInAirMove(self,*args):
  """
  OnPreviewStylusInAirMove(self: ContentElement,e: StylusEventArgs)

   Invoked when an unhandled System.Windows.Input.Stylus.PreviewStylusInAirMove�attached event 

    reaches an element in its route that is derived from this class. Implement this method to add 

    class handling for this event.

  

  

   e: The System.Windows.Input.StylusEventArgs that contains the event data.
  """
  pass
 def OnPreviewStylusInRange(self,*args):
  """
  OnPreviewStylusInRange(self: ContentElement,e: StylusEventArgs)

   Invoked when an unhandled System.Windows.Input.Stylus.PreviewStylusInRange�attached event 

    reaches an element in its route that is derived from this class. Implement this method to add 

    class handling for this event.

  

  

   e: The System.Windows.Input.StylusEventArgs that contains the event data.
  """
  pass
 def OnPreviewStylusMove(self,*args):
  """
  OnPreviewStylusMove(self: ContentElement,e: StylusEventArgs)

   Invoked when an unhandled System.Windows.Input.Stylus.PreviewStylusMove�attached event reaches 

    an element in its route that is derived from this class. Implement this method to add class 

    handling for this event.

  

  

   e: The System.Windows.Input.StylusEventArgs that contains the event data.
  """
  pass
 def OnPreviewStylusOutOfRange(self,*args):
  """
  OnPreviewStylusOutOfRange(self: ContentElement,e: StylusEventArgs)

   Invoked when an unhandled System.Windows.Input.Stylus.PreviewStylusOutOfRange�attached event 

    reaches an element in its route that is derived from this class. Implement this method to add 

    class handling for this event.

  

  

   e: The System.Windows.Input.StylusEventArgs that contains the event data.
  """
  pass
 def OnPreviewStylusSystemGesture(self,*args):
  """
  OnPreviewStylusSystemGesture(self: ContentElement,e: StylusSystemGestureEventArgs)

   Invoked when an unhandled System.Windows.Input.Stylus.PreviewStylusSystemGesture�attached event 

    reaches an element in its route that is derived from this class. Implement this method to add 

    class handling for this event.

  

  

   e: The System.Windows.Input.StylusSystemGestureEventArgs that contains the event data.
  """
  pass
 def OnPreviewStylusUp(self,*args):
  """
  OnPreviewStylusUp(self: ContentElement,e: StylusEventArgs)

   Invoked when an unhandled System.Windows.Input.Stylus.PreviewStylusUp�attached event reaches an 

    element in its route that is derived from this class. Implement this method to add class 

    handling for this event.

  

  

   e: The System.Windows.Input.StylusEventArgs that contains the event data.
  """
  pass
 def OnPreviewTextInput(self,*args):
  """
  OnPreviewTextInput(self: ContentElement,e: TextCompositionEventArgs)

   Invoked when an unhandled System.Windows.Input.TextCompositionManager.PreviewTextInput�attached 

    event reaches an element in its route that is derived from this class. Implement this method to 

    add class handling for this event.

  

  

   e: The System.Windows.Input.TextCompositionEventArgs that contains the event data.
  """
  pass
 def OnPreviewTouchDown(self,*args):
  """
  OnPreviewTouchDown(self: ContentElement,e: TouchEventArgs)

   Provides class handling for the System.Windows.ContentElement.PreviewTouchDown routed event that 

    occurs when a touch presses this element.

  

  

   e: A System.Windows.Input.TouchEventArgs that contains the event data.
  """
  pass
 def OnPreviewTouchMove(self,*args):
  """
  OnPreviewTouchMove(self: ContentElement,e: TouchEventArgs)

   Provides class handling for the System.Windows.ContentElement.PreviewTouchMove routed event that 

    occurs when a touch moves while inside this element.

  

  

   e: A System.Windows.Input.TouchEventArgs that contains the event data.
  """
  pass
 def OnPreviewTouchUp(self,*args):
  """
  OnPreviewTouchUp(self: ContentElement,e: TouchEventArgs)

   Provides class handling for the System.Windows.ContentElement.PreviewTouchUp routed event that 

    occurs when a touch is released inside this element.

  

  

   e: A System.Windows.Input.TouchEventArgs that contains the event data.
  """
  pass
 def OnPropertyChanged(self,*args):
  """
  OnPropertyChanged(self: FrameworkContentElement,e: DependencyPropertyChangedEventArgs)

   Invoked whenever the effective value of any dependency property on this 

    System.Windows.FrameworkContentElement has been updated. The specific dependency property that 

    changed is reported in the arguments parameter. Overrides 

    System.Windows.DependencyObject.OnPropertyChanged(System.Windows.DependencyPropertyChangedEventAr

    gs).

  

  

   e: The event data that describes the property that changed,including the old and new values.
  """
  pass
 def OnQueryContinueDrag(self,*args):
  """
  OnQueryContinueDrag(self: ContentElement,e: QueryContinueDragEventArgs)

   Invoked when an unhandled System.Windows.DragDrop.QueryContinueDrag�attached event reaches an 

    element in its route that is derived from this class. Implement this method to add class 

    handling for this event.

  

  

   e: The System.Windows.QueryContinueDragEventArgs that contains the event data.
  """
  pass
 def OnQueryCursor(self,*args):
  """
  OnQueryCursor(self: ContentElement,e: QueryCursorEventArgs)

   Invoked when an unhandled System.Windows.Input.Mouse.QueryCursor�attached event reaches an 

    element in its route that is derived from this class. Implement this method to add class 

    handling for this event.

  

  

   e: The System.Windows.Input.QueryCursorEventArgs that contains the event data.
  """
  pass
 def OnStyleChanged(self,*args):
  """
  OnStyleChanged(self: FrameworkContentElement,oldStyle: Style,newStyle: Style)

   Invoked when the style that is in use on this element changes.

  

   oldStyle: The old style.

   newStyle: The new style.
  """
  pass
 def OnStylusButtonDown(self,*args):
  """
  OnStylusButtonDown(self: ContentElement,e: StylusButtonEventArgs)

   Invoked when an unhandled System.Windows.Input.Stylus.StylusButtonDown�attached event reaches an 

    element in its route that is derived from this class. Implement this method to add class 

    handling for this event.

  

  

   e: The System.Windows.Input.StylusButtonEventArgs that contains the event data.
  """
  pass
 def OnStylusButtonUp(self,*args):
  """
  OnStylusButtonUp(self: ContentElement,e: StylusButtonEventArgs)

   Invoked when an unhandled System.Windows.Input.Stylus.StylusButtonUp�attached event reaches an 

    element in its route that is derived from this class. Implement this method to add class 

    handling for this event.

  

  

   e: The System.Windows.Input.StylusButtonEventArgs that contains the event data.
  """
  pass
 def OnStylusDown(self,*args):
  """
  OnStylusDown(self: ContentElement,e: StylusDownEventArgs)

   Invoked when an unhandled System.Windows.Input.Stylus.StylusDown�attached event reaches an 

    element in its route that is derived from this class. Implement this method to add class 

    handling for this event.

  

  

   e: The System.Windows.Input.StylusDownEventArgs that contains the event data.
  """
  pass
 def OnStylusEnter(self,*args):
  """
  OnStylusEnter(self: ContentElement,e: StylusEventArgs)

   Invoked when an unhandled System.Windows.Input.Stylus.StylusEnter�attached event is raised by 

    this element. Implement this method to add class handling for this event.

  

  

   e: The System.Windows.Input.StylusEventArgs that contains the event data.
  """
  pass
 def OnStylusInAirMove(self,*args):
  """
  OnStylusInAirMove(self: ContentElement,e: StylusEventArgs)

   Invoked when an unhandled System.Windows.Input.Stylus.StylusInAirMove�attached event reaches an 

    element in its route that is derived from this class. Implement this method to add class 

    handling for this event.

  

  

   e: The System.Windows.Input.StylusEventArgs that contains the event data.
  """
  pass
 def OnStylusInRange(self,*args):
  """
  OnStylusInRange(self: ContentElement,e: StylusEventArgs)

   Invoked when an unhandled System.Windows.Input.Stylus.StylusInRange�attached event reaches an 

    element in its route that is derived from this class. Implement this method to add class 

    handling for this event.

  

  

   e: The System.Windows.Input.StylusEventArgs that contains the event data.
  """
  pass
 def OnStylusLeave(self,*args):
  """
  OnStylusLeave(self: ContentElement,e: StylusEventArgs)

   Invoked when an unhandled System.Windows.Input.Stylus.StylusLeave�attached event is raised by 

    this element. Implement this method to add class handling for this event.

  

  

   e: The System.Windows.Input.StylusEventArgs that contains the event data.
  """
  pass
 def OnStylusMove(self,*args):
  """
  OnStylusMove(self: ContentElement,e: StylusEventArgs)

   Invoked when an unhandled System.Windows.Input.Stylus.StylusMove�attached event reaches an 

    element in its route that is derived from this class. Implement this method to add class 

    handling for this event.

  

  

   e: The System.Windows.Input.StylusEventArgs that contains the event data.
  """
  pass
 def OnStylusOutOfRange(self,*args):
  """
  OnStylusOutOfRange(self: ContentElement,e: StylusEventArgs)

   Invoked when an unhandled System.Windows.Input.Stylus.StylusOutOfRange�attached event reaches an 

    element in its route that is derived from this class. Implement this method to add class 

    handling for this event.

  

  

   e: The System.Windows.Input.StylusEventArgs that contains the event data.
  """
  pass
 def OnStylusSystemGesture(self,*args):
  """
  OnStylusSystemGesture(self: ContentElement,e: StylusSystemGestureEventArgs)

   Invoked when an unhandled System.Windows.Input.Stylus.StylusSystemGesture�attached event reaches 

    an element in its route that is derived from this class. Implement this method to add class 

    handling for this event.

  

  

   e: The System.Windows.Input.StylusSystemGestureEventArgs that contains the event data.
  """
  pass
 def OnStylusUp(self,*args):
  """
  OnStylusUp(self: ContentElement,e: StylusEventArgs)

   Invoked when an unhandled System.Windows.Input.Stylus.StylusUp�attached event reaches an element 

    in its route that is derived from this class. Implement this method to add class handling for 

    this event.

  

  

   e: The System.Windows.Input.StylusEventArgs that contains the event data.
  """
  pass
 def OnTextInput(self,*args):
  """
  OnTextInput(self: ContentElement,e: TextCompositionEventArgs)

   Invoked when an unhandled System.Windows.Input.TextCompositionManager.TextInput�attached event 

    reaches an element in its route that is derived from this class. Implement this method to add 

    class handling for this event.

  

  

   e: The System.Windows.Input.TextCompositionEventArgs that contains the event data.
  """
  pass
 def OnToolTipClosing(self,*args):
  """
  OnToolTipClosing(self: FrameworkContentElement,e: ToolTipEventArgs)

   Invoked whenever the System.Windows.FrameworkContentElement.ToolTipClosing routed event reaches 

    this class in its route. Implement this method to add class handling for this event.

  

  

   e: Provides data about the event.
  """
  pass
 def OnToolTipOpening(self,*args):
  """
  OnToolTipOpening(self: FrameworkContentElement,e: ToolTipEventArgs)

   Invoked whenever the System.Windows.FrameworkContentElement.ToolTipOpening routed event reaches 

    this class in its route. Implement this method to add class handling for this event.

  

  

   e: Provides data about the event.
  """
  pass
 def OnTouchDown(self,*args):
  """
  OnTouchDown(self: ContentElement,e: TouchEventArgs)

   Provides class handling for the System.Windows.ContentElement.TouchDown routed event that occurs 

    when a touch presses inside this element.

  

  

   e: A System.Windows.Input.TouchEventArgs that contains the event data.
  """
  pass
 def OnTouchEnter(self,*args):
  """
  OnTouchEnter(self: ContentElement,e: TouchEventArgs)

   Provides class handling for the System.Windows.ContentElement.TouchEnter routed event that 

    occurs when a touch moves from outside to inside the bounds of this element.

  

  

   e: A System.Windows.Input.TouchEventArgs that contains the event data.
  """
  pass
 def OnTouchLeave(self,*args):
  """
  OnTouchLeave(self: ContentElement,e: TouchEventArgs)

   Provides class handling for the System.Windows.ContentElement.TouchLeave routed event that 

    occurs when a touch moves from inside to outside the bounds of this element.

  

  

   e: A System.Windows.Input.TouchEventArgs that contains the event data.
  """
  pass
 def OnTouchMove(self,*args):
  """
  OnTouchMove(self: ContentElement,e: TouchEventArgs)

   Provides class handling for the System.Windows.ContentElement.TouchMove routed event that occurs 

    when a touch moves while inside this element.

  

  

   e: A System.Windows.Input.TouchEventArgs that contains the event data.
  """
  pass
 def OnTouchUp(self,*args):
  """
  OnTouchUp(self: ContentElement,e: TouchEventArgs)

   Provides class handling for the System.Windows.ContentElement.TouchUp routed event that occurs 

    when a touch is released inside this element.

  

  

   e: A System.Windows.Input.TouchEventArgs that contains the event data.
  """
  pass
 def RemoveLogicalChild(self,*args):
  """
  RemoveLogicalChild(self: FrameworkContentElement,child: object)

   Removes the specified element from the logical tree for this element.

  

   child: The element to remove.
  """
  pass
 def ShouldSerializeProperty(self,*args):
  """
  ShouldSerializeProperty(self: DependencyObject,dp: DependencyProperty) -> bool

  

   Returns a value that indicates whether serialization processes should serialize the value for 

    the provided dependency property.

  

  

   dp: The identifier for the dependency property that should be serialized.

   Returns: true if the dependency property that is supplied should be value-serialized; otherwise,false.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 DefaultStyleKey=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the key to use to find the style template for this control in themes.



"""

 IsEnabledCore=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that becomes the return value of System.Windows.ContentElement.IsEnabled in derived classes.



"""

 LogicalChildren=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets an enumerator for the logical child elements of this element.



"""

 SharedSizeGroup=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that identifies a System.Windows.Controls.ColumnDefinition or System.Windows.Controls.RowDefinition as a member of a defined group that shares sizing properties.



Get: SharedSizeGroup(self: DefinitionBase) -> str



Set: SharedSizeGroup(self: DefinitionBase)=value

"""


 SharedSizeGroupProperty=None




class IndexOutOfRangeException(SystemException,ISerializable,_Exception):
 """
 The exception that is thrown when an attempt is made to access an element of an array with an index that is outside the bounds of the array. This class cannot be inherited.

 

 IndexOutOfRangeException()

 IndexOutOfRangeException(message: str)

 IndexOutOfRangeException(message: str,innerException: Exception)
 """
 def add_SerializeObjectState(self,*args):
  """ add_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def remove_SerializeObjectState(self,*args):
  """ remove_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,message=None,innerException=None):
  """
  __new__(cls: type)

  __new__(cls: type,message: str)

  __new__(cls: type,message: str,innerException: Exception)
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass



class NetworkCredential(object,ICredentials,ICredentialsByHost):
 """
 Provides credentials for password-based authentication schemes such as basic,digest,NTLM,and Kerberos authentication.

 

 NetworkCredential(userName: str,password: str)

 NetworkCredential()

 NetworkCredential(userName: str,password: SecureString)

 NetworkCredential(userName: str,password: str,domain: str)

 NetworkCredential(userName: str,password: SecureString,domain: str)
 """
 def GetCredential(self,*__args):
  """
  GetCredential(self: NetworkCredential,host: str,port: int,authenticationType: str) -> NetworkCredential

  

   Returns an instance of the System.Net.NetworkCredential class for the specified host,port,and 

    authentication type.

  

  

   host: The host computer that authenticates the client.

   port: The port on the host that the client communicates with.

   authenticationType: The type of authentication requested,as defined in the 

    System.Net.IAuthenticationModule.AuthenticationType property.

  

   Returns: A System.Net.NetworkCredential for the specified host,port,and authentication protocol,or 

    null if there are no credentials available for the specified host,port,and authentication 

    protocol.

  

  GetCredential(self: NetworkCredential,uri: Uri,authType: str) -> NetworkCredential

  

   Returns an instance of the System.Net.NetworkCredential class for the specified Uniform Resource 

    Identifier (URI) and authentication type.

  

  

   uri: The URI that the client provides authentication for.

   authType: The type of authentication requested,as defined in the 

    System.Net.IAuthenticationModule.AuthenticationType property.

  

   Returns: A System.Net.NetworkCredential object.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,userName=None,password=None,domain=None):
  """
  __new__(cls: type)

  __new__(cls: type,userName: str,password: str)

  __new__(cls: type,userName: str,password: SecureString)

  __new__(cls: type,userName: str,password: str,domain: str)

  __new__(cls: type,userName: str,password: SecureString,domain: str)
  """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 Domain=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the domain or computer name that verifies the credentials.



Get: Domain(self: NetworkCredential) -> str



Set: Domain(self: NetworkCredential)=value

"""

 Password=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the password for the user name associated with the credentials.



Get: Password(self: NetworkCredential) -> str



Set: Password(self: NetworkCredential)=value

"""

 SecurePassword=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the password as a System.Security.SecureString instance.



Get: SecurePassword(self: NetworkCredential) -> SecureString



Set: SecurePassword(self: NetworkCredential)=value

"""

 UserName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the user name associated with the credentials.



Get: UserName(self: NetworkCredential) -> str



Set: UserName(self: NetworkCredential)=value

"""





class DefaultEventAttribute(Attribute,_Attribute):
 """
 Specifies the default event for a component.

 

 DefaultEventAttribute(name: str)
 """
 def Equals(self,obj):
  """
  Equals(self: DefaultEventAttribute,obj: object) -> bool

  

   Returns whether the value of the given object is equal to the current 

    System.ComponentModel.DefaultEventAttribute.

  

  

   obj: The object to test the value equality of.

   Returns: true if the value of the given object is equal to that of the current; otherwise,false.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: DefaultEventAttribute) -> int

  

   Returns the hash code for this instance.

   Returns: A 32-bit signed integer hash code.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,name):
  """ __new__(cls: type,name: str) """
  pass
 def __ne__(self,*args):
  pass
 Name=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the name of the default event for the component this attribute is bound to.



Get: Name(self: DefaultEventAttribute) -> str



"""


 Default=None




class DataGridRowEventArgs(EventArgs):
 """
 Provides data for the System.Windows.Controls.DataGrid.LoadingRow and System.Windows.Controls.DataGrid.UnloadingRow events.

 

 DataGridRowEventArgs(row: DataGridRow)
 """
 @staticmethod
 def __new__(self,row):
  """ __new__(cls: type,row: DataGridRow) """
  pass
 Row=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the row for which the event occurred.



Get: Row(self: DataGridRowEventArgs) -> DataGridRow



"""





class CustomAce(GenericAce):
 """
 Represents an Access Control Entry (ACE) that is not defined by one of the members of the System.Security.AccessControl.AceType enumeration.

 

 CustomAce(type: AceType,flags: AceFlags,opaque: Array[Byte])
 """
 def GetBinaryForm(self,binaryForm,offset):
  """
  GetBinaryForm(self: CustomAce,binaryForm: Array[Byte],offset: int)

   Marshals the contents of the System.Security.AccessControl.CustomAce object into the specified 

    byte array beginning at the specified offset.

  

  

   binaryForm: The byte array into which the contents of the System.Security.AccessControl.CustomAce is 

    marshaled.

  

   offset: The offset at which to start marshaling.
  """
  pass
 def GetOpaque(self):
  """
  GetOpaque(self: CustomAce) -> Array[Byte]

  

   Returns the opaque data associated with this System.Security.AccessControl.CustomAce object.

   Returns: An array of byte values that represents the opaque data associated with this 

    System.Security.AccessControl.CustomAce object.
  """
  pass
 def SetOpaque(self,opaque):
  """
  SetOpaque(self: CustomAce,opaque: Array[Byte])

   Sets the opaque callback data associated with this System.Security.AccessControl.CustomAce 

    object.

  

  

   opaque: An array of byte values that represents the opaque callback data for this 

    System.Security.AccessControl.CustomAce object.
  """
  pass
 @staticmethod
 def __new__(self,type,flags,opaque):
  """ __new__(cls: type,type: AceType,flags: AceFlags,opaque: Array[Byte]) """
  pass
 BinaryLength=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the length,in bytes,of the binary representation of the current System.Security.AccessControl.CustomAce object. This length should be used before marshaling the ACL into a binary array with the System.Security.AccessControl.CustomAce.GetBinaryForm method.



Get: BinaryLength(self: CustomAce) -> int



"""

 OpaqueLength=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the length of the opaque data associated with this System.Security.AccessControl.CustomAce object.



Get: OpaqueLength(self: CustomAce) -> int



"""


 MaxOpaqueLength=65531




class SystemParameter(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the system parameter type.

 

 enum SystemParameter,values: CaretWidthMetric (8),DropShadow (0),FlatMenu (1),FontSmoothingContrastMetric (2),FontSmoothingTypeMetric (3),HorizontalFocusThicknessMetric (10),MenuFadeEnabled (4),SelectionFade (5),ToolTipAnimationMetric (6),UIEffects (7),VerticalFocusThicknessMetric (9)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 CaretWidthMetric=None
 DropShadow=None
 FlatMenu=None
 FontSmoothingContrastMetric=None
 FontSmoothingTypeMetric=None
 HorizontalFocusThicknessMetric=None
 MenuFadeEnabled=None
 SelectionFade=None
 ToolTipAnimationMetric=None
 UIEffects=None
 value__=None
 VerticalFocusThicknessMetric=None




class IDeviceContext(IDisposable):
 """ Defines methods for obtaining and releasing an existing handle to a Windows device context. """
 def GetHdc(self):
  """
  GetHdc(self: IDeviceContext) -> IntPtr

  

   Returns the handle to a Windows device context.

   Returns: An System.IntPtr representing the handle of a device context.
  """
  pass
 def ReleaseHdc(self):
  """
  ReleaseHdc(self: IDeviceContext)

   Releases the handle of a Windows device context.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass



class DataGridViewPaintParts(Enum,IComparable,IFormattable,IConvertible):
 """
 Defines values for specifying the parts of a System.Windows.Forms.DataGridViewCell that are to be painted.

 

 enum (flags) DataGridViewPaintParts,values: All (127),Background (1),Border (2),ContentBackground (4),ContentForeground (8),ErrorIcon (16),Focus (32),None (0),SelectionBackground (64)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 All=None
 Background=None
 Border=None
 ContentBackground=None
 ContentForeground=None
 ErrorIcon=None
 Focus=None
 None=None
 SelectionBackground=None
 value__=None




class EXCEPINFO(object):
 """ Use System.Runtime.InteropServices.ComTypes.EXCEPINFO instead. """
 bstrDescription=None
 bstrHelpFile=None
 bstrSource=None
 dwHelpContext=None
 pfnDeferredFillIn=None
 pvReserved=None
 wCode=None
 wReserved=None




class TreeNodeMouseClickEventArgs(MouseEventArgs):
 """
 Provides data for the System.Windows.Forms.TreeView.NodeMouseClick and System.Windows.Forms.TreeView.NodeMouseDoubleClick events.

 

 TreeNodeMouseClickEventArgs(node: TreeNode,button: MouseButtons,clicks: int,x: int,y: int)
 """
 @staticmethod
 def __new__(self,node,button,clicks,x,y):
  """ __new__(cls: type,node: TreeNode,button: MouseButtons,clicks: int,x: int,y: int) """
  pass
 Node=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the node that was clicked.



Get: Node(self: TreeNodeMouseClickEventArgs) -> TreeNode



"""





# encoding: utf-8
# module System.Collections.Generic calls itself Generic
# from mscorlib,Version=4.0.0.0,Culture=neutral,PublicKeyToken=b77a5c561934e089,System,Version=4.0.0.0,Culture=neutral,PublicKeyToken=b77a5c561934e089
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes

class Comparer(object,IComparer,IComparer[T]):
 # no doc
 def Compare(self,x,y):
  """
  Compare(self: Comparer[T],x: T,y: T) -> int

  

   When overridden in a derived class,performs a comparison of two objects of the same type and 

    returns a value indicating whether one object is less than,equal to,or greater than the other.

  

  

   x: The first object to compare.

   y: The second object to compare.

   Returns: A signed integer that indicates the relative values of x and y,as shown in the following 

    table.Value Meaning Less than zero x is less than y.Zero x equals y.Greater than zero x is 

    greater than y.
  """
  pass
 @staticmethod
 def Create(comparison):
  """ Create(comparison: Comparison[T]) -> Comparer[T] """
  pass
 def __cmp__(self,*args):
  """ x.__cmp__(y) <==> cmp(x,y) """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass

class Dictionary(object,IDictionary[TKey,TValue],ICollection[KeyValuePair[TKey,TValue]],IEnumerable[KeyValuePair[TKey,TValue]],IEnumerable,IDictionary,ICollection,IReadOnlyDictionary[TKey,TValue],IReadOnlyCollection[KeyValuePair[TKey,TValue]],ISerializable,IDeserializationCallback):
 """
 Dictionary[TKey,TValue]()

 Dictionary[TKey,TValue](capacity: int)

 Dictionary[TKey,TValue](comparer: IEqualityComparer[TKey])

 Dictionary[TKey,TValue](capacity: int,comparer: IEqualityComparer[TKey])

 Dictionary[TKey,TValue](dictionary: IDictionary[TKey,TValue])

 Dictionary[TKey,TValue](dictionary: IDictionary[TKey,TValue],comparer: IEqualityComparer[TKey])
 """
 def Add(self,key,value):
  """
  Add(self: Dictionary[TKey,TValue],key: TKey,value: TValue)

   Adds the specified key and value to the dictionary.

  

   key: The key of the element to add.

   value: The value of the element to add. The value can be null for reference types.
  """
  pass
 def Clear(self):
  """
  Clear(self: Dictionary[TKey,TValue])

   Removes all keys and values from the System.Collections.Generic.Dictionary.
  """
  pass
 def ContainsKey(self,key):
  """
  ContainsKey(self: Dictionary[TKey,TValue],key: TKey) -> bool

  

   Determines whether the System.Collections.Generic.Dictionary contains the specified key.

  

   key: The key to locate in the System.Collections.Generic.Dictionary.

   Returns: true if the System.Collections.Generic.Dictionary contains an element with the specified key; 

    otherwise,false.
  """
  pass
 def ContainsValue(self,value):
  """
  ContainsValue(self: Dictionary[TKey,TValue],value: TValue) -> bool

  

   Determines whether the System.Collections.Generic.Dictionary contains a specific value.

  

   value: The value to locate in the System.Collections.Generic.Dictionary. The value can be null for 

    reference types.

  

   Returns: true if the System.Collections.Generic.Dictionary contains an element with the specified value; 

    otherwise,false.
  """
  pass
 def GetEnumerator(self):
  """
  GetEnumerator(self: Dictionary[TKey,TValue]) -> Enumerator

  

   Returns an enumerator that iterates through the System.Collections.Generic.Dictionary.

   Returns: A System.Collections.Generic.Dictionary structure for the System.Collections.Generic.Dictionary.
  """
  pass
 def GetObjectData(self,info,context):
  """
  GetObjectData(self: Dictionary[TKey,TValue],info: SerializationInfo,context: StreamingContext)

   Implements the System.Runtime.Serialization.ISerializable interface and returns the data needed 

    to serialize the System.Collections.Generic.Dictionary instance.

  

  

   info: A System.Runtime.Serialization.SerializationInfo object that contains the information required 

    to serialize the System.Collections.Generic.Dictionary instance.

  

   context: A System.Runtime.Serialization.StreamingContext structure that contains the source and 

    destination of the serialized stream associated with the System.Collections.Generic.Dictionary 

    instance.
  """
  pass
 def OnDeserialization(self,sender):
  """
  OnDeserialization(self: Dictionary[TKey,TValue],sender: object)

   Implements the System.Runtime.Serialization.ISerializable interface and raises the 

    deserialization event when the deserialization is complete.

  

  

   sender: The source of the deserialization event.
  """
  pass
 def Remove(self,key):
  """
  Remove(self: Dictionary[TKey,TValue],key: TKey) -> bool

  

   Removes the value with the specified key from the System.Collections.Generic.Dictionary.

  

   key: The key of the element to remove.

   Returns: true if the element is successfully found and removed; otherwise,false.  This method returns 

    false if key is not found in the System.Collections.Generic.Dictionary.
  """
  pass
 def TryGetValue(self,key,value):
  """ TryGetValue(self: Dictionary[TKey,TValue],key: TKey) -> (bool,TValue) """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __contains__(self,*args):
  """
  __contains__(self: IDictionary[TKey,TValue],key: TKey) -> bool

  

   Determines whether the System.Collections.Generic.IDictionary contains an element with the 

    specified key.

  

  

   key: The key to locate in the System.Collections.Generic.IDictionary.

   Returns: true if the System.Collections.Generic.IDictionary contains an element with the key; otherwise,

    false.

  

  __contains__(self: IDictionary,key: object) -> bool

  

   Determines whether the System.Collections.IDictionary object contains an element with the 

    specified key.

  

  

   key: The key to locate in the System.Collections.IDictionary object.

   Returns: true if the System.Collections.IDictionary contains an element with the key; otherwise,false.
  """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __len__(self,*args):
  """ x.__len__() <==> len(x) """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type)

  __new__(cls: type,capacity: int)

  __new__(cls: type,comparer: IEqualityComparer[TKey])

  __new__(cls: type,capacity: int,comparer: IEqualityComparer[TKey])

  __new__(cls: type,dictionary: IDictionary[TKey,TValue])

  __new__(cls: type,dictionary: IDictionary[TKey,TValue],comparer: IEqualityComparer[TKey])

  __new__(cls: type,info: SerializationInfo,context: StreamingContext)
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __repr__(self,*args):
  """
  __repr__(self: Dictionary[TKey,TValue]) -> str

  __repr__(self: Dictionary[K,V]) -> str
  """
  pass
 def __setitem__(self,*args):
  """ x.__setitem__(i,y) <==> x[i]= """
  pass
 Comparer=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Collections.Generic.IEqualityComparer that is used to determine equality of keys for the dictionary.



Get: Comparer(self: Dictionary[TKey,TValue]) -> IEqualityComparer[TKey]



"""

 Count=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the number of key/value pairs contained in the System.Collections.Generic.Dictionary.



Get: Count(self: Dictionary[TKey,TValue]) -> int



"""

 Keys=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a collection containing the keys in the System.Collections.Generic.Dictionary.



Get: Keys(self: Dictionary[TKey,TValue]) -> KeyCollection



"""

 Values=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a collection containing the values in the System.Collections.Generic.Dictionary.



Get: Values(self: Dictionary[TKey,TValue]) -> ValueCollection



"""


 Enumerator=None
 KeyCollection=None
 ValueCollection=None


class EqualityComparer(object,IEqualityComparer,IEqualityComparer[T]):
 # no doc
 def Equals(self,*__args):
  """
  Equals(self: EqualityComparer[T],x: T,y: T) -> bool

  

   When overridden in a derived class,determines whether two objects of type T are equal.

  

   x: The first object to compare.

   y: The second object to compare.

   Returns: true if the specified objects are equal; otherwise,false.
  """
  pass
 def GetHashCode(self,obj=None):
  """
  GetHashCode(self: EqualityComparer[T],obj: T) -> int

  

   When overridden in a derived class,serves as a hash function for the specified object for 

    hashing algorithms and data structures,such as a hash table.

  

  

   obj: The object for which to get a hash code.

   Returns: A hash code for the specified object.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass

class ICollection(IEnumerable[T],IEnumerable):
 # no doc
 def Add(self,item):
  """
  Add(self: ICollection[T],item: T)

   Adds an item to the System.Collections.Generic.ICollection.

  

   item: The object to add to the System.Collections.Generic.ICollection.
  """
  pass
 def Clear(self):
  """
  Clear(self: ICollection[T])

   Removes all items from the System.Collections.Generic.ICollection.
  """
  pass
 def Contains(self,item):
  """
  Contains(self: ICollection[T],item: T) -> bool

  

   Determines whether the System.Collections.Generic.ICollection contains a specific value.

  

   item: The object to locate in the System.Collections.Generic.ICollection.

   Returns: true if item is found in the System.Collections.Generic.ICollection; otherwise,false.
  """
  pass
 def CopyTo(self,array,arrayIndex):
  """ CopyTo(self: ICollection[T],array: Array[T],arrayIndex: int) """
  pass
 def Remove(self,item):
  """
  Remove(self: ICollection[T],item: T) -> bool

  

   Removes the first occurrence of a specific object from the 

    System.Collections.Generic.ICollection.

  

  

   item: The object to remove from the System.Collections.Generic.ICollection.

   Returns: true if item was successfully removed from the System.Collections.Generic.ICollection; 

    otherwise,false. This method also returns false if item is not found in the original 

    System.Collections.Generic.ICollection.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __contains__(self,*args):
  """ __contains__[T](enumerable: IEnumerable[T],value: T) -> bool """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 Count=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the number of elements contained in the System.Collections.Generic.ICollection.



Get: Count(self: ICollection[T]) -> int



"""

 IsReadOnly=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the System.Collections.Generic.ICollection is read-only.



Get: IsReadOnly(self: ICollection[T]) -> bool



"""



class IComparer:
 # no doc
 def Compare(self,x,y):
  """
  Compare(self: IComparer[T],x: T,y: T) -> int

  

   Compares two objects and returns a value indicating whether one is less than,equal to,or 

    greater than the other.

  

  

   x: The first object to compare.

   y: The second object to compare.

   Returns: A signed integer that indicates the relative values of x and y,as shown in the following 

    table.Value Meaning Less than zerox is less than y.Zerox equals y.Greater than zerox is greater 

    than y.
  """
  pass
 def __cmp__(self,*args):
  """ x.__cmp__(y) <==> cmp(x,y) """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass

class IDictionary(ICollection[KeyValuePair[TKey,TValue]],IEnumerable[KeyValuePair[TKey,TValue]],IEnumerable):
 # no doc
 def Add(self,key,value):
  """
  Add(self: IDictionary[TKey,TValue],key: TKey,value: TValue)

   Adds an element with the provided key and value to the System.Collections.Generic.IDictionary.

  

   key: The object to use as the key of the element to add.

   value: The object to use as the value of the element to add.
  """
  pass
 def ContainsKey(self,key):
  """
  ContainsKey(self: IDictionary[TKey,TValue],key: TKey) -> bool

  

   Determines whether the System.Collections.Generic.IDictionary contains an element with the 

    specified key.

  

  

   key: The key to locate in the System.Collections.Generic.IDictionary.

   Returns: true if the System.Collections.Generic.IDictionary contains an element with the key; otherwise,

    false.
  """
  pass
 def Remove(self,key):
  """
  Remove(self: IDictionary[TKey,TValue],key: TKey) -> bool

  

   Removes the element with the specified key from the System.Collections.Generic.IDictionary.

  

   key: The key of the element to remove.

   Returns: true if the element is successfully removed; otherwise,false.  This method also returns false 

    if key was not found in the original System.Collections.Generic.IDictionary.
  """
  pass
 def TryGetValue(self,key,value):
  """ TryGetValue(self: IDictionary[TKey,TValue],key: TKey) -> (bool,TValue) """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __contains__(self,*args):
  """ __contains__(self: ICollection[KeyValuePair[TKey,TValue]],item: KeyValuePair[TKey,TValue]) -> bool """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __len__(self,*args):
  """ x.__len__() <==> len(x) """
  pass
 def __setitem__(self,*args):
  """ x.__setitem__(i,y) <==> x[i]= """
  pass
 Keys=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets an System.Collections.Generic.ICollection containing the keys of the System.Collections.Generic.IDictionary.



Get: Keys(self: IDictionary[TKey,TValue]) -> ICollection[TKey]



"""

 Values=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets an System.Collections.Generic.ICollection containing the values in the System.Collections.Generic.IDictionary.



Get: Values(self: IDictionary[TKey,TValue]) -> ICollection[TValue]



"""



class IEnumerable(IEnumerable):
 # no doc
 def GetEnumerator(self):
  """
  GetEnumerator(self: IEnumerable[T]) -> IEnumerator[T]

  

   Returns an enumerator that iterates through the collection.

   Returns: A System.Collections.Generic.IEnumerator that can be used to iterate through the collection.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass

class IEnumerator(IDisposable,IEnumerator):
 # no doc
 def next(self,*args):
  """ next(self: object) -> object """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__[T](self: IEnumerator[T]) -> object """
  pass
 Current=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the element in the collection at the current position of the enumerator.



Get: Current(self: IEnumerator[T]) -> T



"""



class IEqualityComparer:
 # no doc
 def Equals(self,x,y):
  """
  Equals(self: IEqualityComparer[T],x: T,y: T) -> bool

  

   Determines whether the specified objects are equal.

  

   x: The first object of type T to compare.

   y: The second object of type T to compare.

   Returns: true if the specified objects are equal; otherwise,false.
  """
  pass
 def GetHashCode(self,obj):
  """
  GetHashCode(self: IEqualityComparer[T],obj: T) -> int

  

   Returns a hash code for the specified object.

  

   obj: The System.Object for which a hash code is to be returned.

   Returns: A hash code for the specified object.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass

class IList(ICollection[T],IEnumerable[T],IEnumerable):
 # no doc
 def IndexOf(self,item):
  """
  IndexOf(self: IList[T],item: T) -> int

  

   Determines the index of a specific item in the System.Collections.Generic.IList.

  

   item: The object to locate in the System.Collections.Generic.IList.

   Returns: The index of item if found in the list; otherwise,-1.
  """
  pass
 def Insert(self,index,item):
  """
  Insert(self: IList[T],index: int,item: T)

   Inserts an item to the System.Collections.Generic.IList at the specified index.

  

   index: The zero-based index at which item should be inserted.

   item: The object to insert into the System.Collections.Generic.IList.
  """
  pass
 def RemoveAt(self,index):
  """
  RemoveAt(self: IList[T],index: int)

   Removes the System.Collections.Generic.IList item at the specified index.

  

   index: The zero-based index of the item to remove.
  """
  pass
 def __contains__(self,*args):
  """
  __contains__(self: ICollection[T],item: T) -> bool

  

   Determines whether the System.Collections.Generic.ICollection contains a specific value.

  

   item: The object to locate in the System.Collections.Generic.ICollection.

   Returns: true if item is found in the System.Collections.Generic.ICollection; otherwise,false.
  """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __len__(self,*args):
  """ x.__len__() <==> len(x) """
  pass
 def __setitem__(self,*args):
  """ x.__setitem__(i,y) <==> x[i]= """
  pass

class IReadOnlyCollection(IEnumerable[T],IEnumerable):
 # no doc
 def __contains__(self,*args):
  """ __contains__[T](enumerable: IEnumerable[T],value: T) -> bool """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 Count=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: Count(self: IReadOnlyCollection[T]) -> int



"""



class IReadOnlyDictionary(IReadOnlyCollection[KeyValuePair[TKey,TValue]],IEnumerable[KeyValuePair[TKey,TValue]],IEnumerable):
 # no doc
 def ContainsKey(self,key):
  """ ContainsKey(self: IReadOnlyDictionary[TKey,TValue],key: TKey) -> bool """
  pass
 def TryGetValue(self,key,value):
  """ TryGetValue(self: IReadOnlyDictionary[TKey,TValue],key: TKey) -> (bool,TValue) """
  pass
 def __contains__(self,*args):
  """ __contains__[KeyValuePair`2](enumerable: IEnumerable[KeyValuePair[TKey,TValue]],value: KeyValuePair[TKey,TValue]) -> bool """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 Keys=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: Keys(self: IReadOnlyDictionary[TKey,TValue]) -> IEnumerable[TKey]



"""

 Values=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: Values(self: IReadOnlyDictionary[TKey,TValue]) -> IEnumerable[TValue]



"""



class IReadOnlyList(IReadOnlyCollection[T],IEnumerable[T],IEnumerable):
 # no doc
 def __contains__(self,*args):
  """ __contains__[T](enumerable: IEnumerable[T],value: T) -> bool """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass

class ISet(ICollection[T],IEnumerable[T],IEnumerable):
 # no doc
 def Add(self,item):
  """
  Add(self: ISet[T],item: T) -> bool

  

   Adds an element to the current set and returns a value to indicate if the element was 

    successfully added.

  

  

   item: The element to add to the set.

   Returns: true if the element is added to the set; false if the element is already in the set.
  """
  pass
 def ExceptWith(self,other):
  """
  ExceptWith(self: ISet[T],other: IEnumerable[T])

   Removes all elements in the specified collection from the current set.

  

   other: The collection of items to remove from the set.
  """
  pass
 def IntersectWith(self,other):
  """
  IntersectWith(self: ISet[T],other: IEnumerable[T])

   Modifies the current set so that it contains only elements that are also in a specified 

    collection.

  

  

   other: The collection to compare to the current set.
  """
  pass
 def IsProperSubsetOf(self,other):
  """
  IsProperSubsetOf(self: ISet[T],other: IEnumerable[T]) -> bool

  

   Determines whether the current set is a proper (strict) subset of a specified collection.

  

   other: The collection to compare to the current set.

   Returns: true if the current set is a proper subset of other; otherwise,false.
  """
  pass
 def IsProperSupersetOf(self,other):
  """
  IsProperSupersetOf(self: ISet[T],other: IEnumerable[T]) -> bool

  

   Determines whether the current set is a proper (strict) superset of a specified collection.

  

   other: The collection to compare to the current set.

   Returns: true if the current set is a proper superset of other; otherwise,false.
  """
  pass
 def IsSubsetOf(self,other):
  """
  IsSubsetOf(self: ISet[T],other: IEnumerable[T]) -> bool

  

   Determines whether a set is a subset of a specified collection.

  

   other: The collection to compare to the current set.

   Returns: true if the current set is a subset of other; otherwise,false.
  """
  pass
 def IsSupersetOf(self,other):
  """
  IsSupersetOf(self: ISet[T],other: IEnumerable[T]) -> bool

  

   Determines whether the current set is a superset of a specified collection.

  

   other: The collection to compare to the current set.

   Returns: true if the current set is a superset of other; otherwise,false.
  """
  pass
 def Overlaps(self,other):
  """
  Overlaps(self: ISet[T],other: IEnumerable[T]) -> bool

  

   Determines whether the current set overlaps with the specified collection.

  

   other: The collection to compare to the current set.

   Returns: true if the current set and other share at least one common element; otherwise,false.
  """
  pass
 def SetEquals(self,other):
  """
  SetEquals(self: ISet[T],other: IEnumerable[T]) -> bool

  

   Determines whether the current set and the specified collection contain the same elements.

  

   other: The collection to compare to the current set.

   Returns: true if the current set is equal to other; otherwise,false.
  """
  pass
 def SymmetricExceptWith(self,other):
  """
  SymmetricExceptWith(self: ISet[T],other: IEnumerable[T])

   Modifies the current set so that it contains only elements that are present either in the 

    current set or in the specified collection,but not both.

  

  

   other: The collection to compare to the current set.
  """
  pass
 def UnionWith(self,other):
  """
  UnionWith(self: ISet[T],other: IEnumerable[T])

   Modifies the current set so that it contains all elements that are present in both the current 

    set and in the specified collection.

  

  

   other: The collection to compare to the current set.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __contains__(self,*args):
  """
  __contains__(self: ICollection[T],item: T) -> bool

  

   Determines whether the System.Collections.Generic.ICollection contains a specific value.

  

   item: The object to locate in the System.Collections.Generic.ICollection.

   Returns: true if item is found in the System.Collections.Generic.ICollection; otherwise,false.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __len__(self,*args):
  """ x.__len__() <==> len(x) """
  pass

class KeyNotFoundException(SystemException,ISerializable,_Exception):
 """
 The exception that is thrown when the key specified for accessing an element in a collection does not match any key in the collection.

 

 KeyNotFoundException()

 KeyNotFoundException(message: str)

 KeyNotFoundException(message: str,innerException: Exception)
 """
 def add_SerializeObjectState(self,*args):
  """ add_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def remove_SerializeObjectState(self,*args):
  """ remove_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,message=None,innerException=None):
  """
  __new__(cls: type)

  __new__(cls: type,message: str)

  __new__(cls: type,message: str,innerException: Exception)

  __new__(cls: type,info: SerializationInfo,context: StreamingContext)
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass

class KeyValuePair(object):
 """ KeyValuePair[TKey,TValue](key: TKey,value: TValue) """
 def ToString(self):
  """
  ToString(self: KeyValuePair[TKey,TValue]) -> str

  

   Returns a string representation of the System.Collections.Generic.KeyValuePair,using the string 

    representations of the key and value.

  

   Returns: A string representation of the System.Collections.Generic.KeyValuePair,which includes the 

    string representations of the key and value.
  """
  pass
 @staticmethod
 def __new__(self,key,value):
  """
  __new__(cls: type,key: TKey,value: TValue)

  __new__[KeyValuePair`2]() -> KeyValuePair[TKey,TValue]
  """
  pass
 Key=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the key in the key/value pair.



Get: Key(self: KeyValuePair[TKey,TValue]) -> TKey



"""

 Value=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the value in the key/value pair.



Get: Value(self: KeyValuePair[TKey,TValue]) -> TValue



"""



class LinkedList(object,ICollection[T],IEnumerable[T],IEnumerable,ICollection,IReadOnlyCollection[T],ISerializable,IDeserializationCallback):
 """
 LinkedList[T]()

 LinkedList[T](collection: IEnumerable[T])
 """
 def AddAfter(self,node,*__args):
  """
  AddAfter(self: LinkedList[T],node: LinkedListNode[T],value: T) -> LinkedListNode[T]

  

   Adds a new node containing the specified value after the specified existing node in the 

    System.Collections.Generic.LinkedList.

  

  

   node: The System.Collections.Generic.LinkedListNode after which to insert a new 

    System.Collections.Generic.LinkedListNode containing value.

  

   value: The value to add to the System.Collections.Generic.LinkedList.

   Returns: The new System.Collections.Generic.LinkedListNode containing value.

  AddAfter(self: LinkedList[T],node: LinkedListNode[T],newNode: LinkedListNode[T])

   Adds the specified new node after the specified existing node in the 

    System.Collections.Generic.LinkedList.

  

  

   node: The System.Collections.Generic.LinkedListNode after which to insert newNode.

   newNode: The new System.Collections.Generic.LinkedListNode to add to the 

    System.Collections.Generic.LinkedList.
  """
  pass
 def AddBefore(self,node,*__args):
  """
  AddBefore(self: LinkedList[T],node: LinkedListNode[T],newNode: LinkedListNode[T])

   Adds the specified new node before the specified existing node in the 

    System.Collections.Generic.LinkedList.

  

  

   node: The System.Collections.Generic.LinkedListNode before which to insert newNode.

   newNode: The new System.Collections.Generic.LinkedListNode to add to the 

    System.Collections.Generic.LinkedList.

  

  AddBefore(self: LinkedList[T],node: LinkedListNode[T],value: T) -> LinkedListNode[T]

  

   Adds a new node containing the specified value before the specified existing node in the 

    System.Collections.Generic.LinkedList.

  

  

   node: The System.Collections.Generic.LinkedListNode before which to insert a new 

    System.Collections.Generic.LinkedListNode containing value.

  

   value: The value to add to the System.Collections.Generic.LinkedList.

   Returns: The new System.Collections.Generic.LinkedListNode containing value.
  """
  pass
 def AddFirst(self,*__args):
  """
  AddFirst(self: LinkedList[T],node: LinkedListNode[T])

   Adds the specified new node at the start of the System.Collections.Generic.LinkedList.

  

   node: The new System.Collections.Generic.LinkedListNode to add at the start of the 

    System.Collections.Generic.LinkedList.

  

  AddFirst(self: LinkedList[T],value: T) -> LinkedListNode[T]

  

   Adds a new node containing the specified value at the start of the 

    System.Collections.Generic.LinkedList.

  

  

   value: The value to add at the start of the System.Collections.Generic.LinkedList.

   Returns: The new System.Collections.Generic.LinkedListNode containing value.
  """
  pass
 def AddLast(self,*__args):
  """
  AddLast(self: LinkedList[T],node: LinkedListNode[T])

   Adds the specified new node at the end of the System.Collections.Generic.LinkedList.

  

   node: The new System.Collections.Generic.LinkedListNode to add at the end of the 

    System.Collections.Generic.LinkedList.

  

  AddLast(self: LinkedList[T],value: T) -> LinkedListNode[T]

  

   Adds a new node containing the specified value at the end of the 

    System.Collections.Generic.LinkedList.

  

  

   value: The value to add at the end of the System.Collections.Generic.LinkedList.

   Returns: The new System.Collections.Generic.LinkedListNode containing value.
  """
  pass
 def Clear(self):
  """
  Clear(self: LinkedList[T])

   Removes all nodes from the System.Collections.Generic.LinkedList.
  """
  pass
 def Contains(self,value):
  """
  Contains(self: LinkedList[T],value: T) -> bool

  

   Determines whether a value is in the System.Collections.Generic.LinkedList.

  

   value: The value to locate in the System.Collections.Generic.LinkedList. The value can be null for 

    reference types.

  

   Returns: true if value is found in the System.Collections.Generic.LinkedList; otherwise,false.
  """
  pass
 def CopyTo(self,array,index):
  """ CopyTo(self: LinkedList[T],array: Array[T],index: int) """
  pass
 def Find(self,value):
  """
  Find(self: LinkedList[T],value: T) -> LinkedListNode[T]

  

   Finds the first node that contains the specified value.

  

   value: The value to locate in the System.Collections.Generic.LinkedList.

   Returns: The first System.Collections.Generic.LinkedListNode that contains the specified value,if found; 

    otherwise,null.
  """
  pass
 def FindLast(self,value):
  """
  FindLast(self: LinkedList[T],value: T) -> LinkedListNode[T]

  

   Finds the last node that contains the specified value.

  

   value: The value to locate in the System.Collections.Generic.LinkedList.

   Returns: The last System.Collections.Generic.LinkedListNode that contains the specified value,if found; 

    otherwise,null.
  """
  pass
 def GetEnumerator(self):
  """
  GetEnumerator(self: LinkedList[T]) -> Enumerator

  

   Returns an enumerator that iterates through the System.Collections.Generic.LinkedList.

   Returns: An System.Collections.Generic.LinkedList for the System.Collections.Generic.LinkedList.
  """
  pass
 def GetObjectData(self,info,context):
  """
  GetObjectData(self: LinkedList[T],info: SerializationInfo,context: StreamingContext)

   Implements the System.Runtime.Serialization.ISerializable interface and returns the data needed 

    to serialize the System.Collections.Generic.LinkedList instance.

  

  

   info: A System.Runtime.Serialization.SerializationInfo object that contains the information required 

    to serialize the System.Collections.Generic.LinkedList instance.

  

   context: A System.Runtime.Serialization.StreamingContext object that contains the source and destination 

    of the serialized stream associated with the System.Collections.Generic.LinkedList instance.
  """
  pass
 def OnDeserialization(self,sender):
  """
  OnDeserialization(self: LinkedList[T],sender: object)

   Implements the System.Runtime.Serialization.ISerializable interface and raises the 

    deserialization event when the deserialization is complete.

  

  

   sender: The source of the deserialization event.
  """
  pass
 def Remove(self,*__args):
  """
  Remove(self: LinkedList[T],node: LinkedListNode[T])

   Removes the specified node from the System.Collections.Generic.LinkedList.

  

   node: The System.Collections.Generic.LinkedListNode to remove from the 

    System.Collections.Generic.LinkedList.

  

  Remove(self: LinkedList[T],value: T) -> bool

  

   Removes the first occurrence of the specified value from the 

    System.Collections.Generic.LinkedList.

  

  

   value: The value to remove from the System.Collections.Generic.LinkedList.

   Returns: true if the element containing value is successfully removed; otherwise,false.  This method 

    also returns false if value was not found in the original System.Collections.Generic.LinkedList.
  """
  pass
 def RemoveFirst(self):
  """
  RemoveFirst(self: LinkedList[T])

   Removes the node at the start of the System.Collections.Generic.LinkedList.
  """
  pass
 def RemoveLast(self):
  """
  RemoveLast(self: LinkedList[T])

   Removes the node at the end of the System.Collections.Generic.LinkedList.
  """
  pass
 def __contains__(self,*args):
  """
  __contains__(self: ICollection[T],item: T) -> bool

  

   Determines whether the System.Collections.Generic.ICollection contains a specific value.

  

   item: The object to locate in the System.Collections.Generic.ICollection.

   Returns: true if item is found in the System.Collections.Generic.ICollection; otherwise,false.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __len__(self,*args):
  """ x.__len__() <==> len(x) """
  pass
 @staticmethod
 def __new__(self,collection=None):
  """
  __new__(cls: type)

  __new__(cls: type,collection: IEnumerable[T])

  __new__(cls: type,info: SerializationInfo,context: StreamingContext)
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 Count=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the number of nodes actually contained in the System.Collections.Generic.LinkedList.



Get: Count(self: LinkedList[T]) -> int



"""

 First=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the first node of the System.Collections.Generic.LinkedList.



Get: First(self: LinkedList[T]) -> LinkedListNode[T]



"""

 Last=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the last node of the System.Collections.Generic.LinkedList.



Get: Last(self: LinkedList[T]) -> LinkedListNode[T]



"""


 Enumerator=None


class LinkedListNode(object):
 """ LinkedListNode[T](value: T) """
 @staticmethod
 def __new__(self,value):
  """ __new__(cls: type,value: T) """
  pass
 List=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Collections.Generic.LinkedList that the System.Collections.Generic.LinkedListNode belongs to.



Get: List(self: LinkedListNode[T]) -> LinkedList[T]



"""

 Next=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the next node in the System.Collections.Generic.LinkedList.



Get: Next(self: LinkedListNode[T]) -> LinkedListNode[T]



"""

 Previous=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the previous node in the System.Collections.Generic.LinkedList.



Get: Previous(self: LinkedListNode[T]) -> LinkedListNode[T]



"""

 Value=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the value contained in the node.



Get: Value(self: LinkedListNode[T]) -> T



Set: Value(self: LinkedListNode[T])=value

"""



class List(object,IList[T],ICollection[T],IEnumerable[T],IEnumerable,IList,ICollection,IReadOnlyList[T],IReadOnlyCollection[T]):
 """
 List[T]()

 List[T](capacity: int)

 List[T](collection: IEnumerable[T])
 """
 def Add(self,item):
  """
  Add(self: List[T],item: T)

   Adds an object to the end of the System.Collections.Generic.List.

  

   item: The object to be added to the end of the System.Collections.Generic.List. The value can be null 

    for reference types.
  """
  pass
 def AddRange(self,collection):
  """
  AddRange(self: List[T],collection: IEnumerable[T])

   Adds the elements of the specified collection to the end of the System.Collections.Generic.List.

  

   collection: The collection whose elements should be added to the end of the System.Collections.Generic.List. 

    The collection itself cannot be null,but it can contain elements that are null,if type T is a 

    reference type.
  """
  pass
 def AsReadOnly(self):
  """
  AsReadOnly(self: List[T]) -> ReadOnlyCollection[T]

  

   Returns a read-only System.Collections.Generic.IList wrapper for the current collection.

   Returns: A System.Collections.ObjectModel.ReadOnlyCollection that acts as a read-only wrapper around the 

    current System.Collections.Generic.List.
  """
  pass
 def BinarySearch(self,*__args):
  """
  BinarySearch(self: List[T],item: T,comparer: IComparer[T]) -> int

  

   Searches the entire sorted System.Collections.Generic.List for an element using the specified 

    comparer and returns the zero-based index of the element.

  

  

   item: The object to locate. The value can be null for reference types.

   comparer: The System.Collections.Generic.IComparer implementation to use when comparing elements.-or-null 

    to use the default comparer System.Collections.Generic.Comparer.

  

   Returns: The zero-based index of item in the sorted System.Collections.Generic.List,if item is found; 

    otherwise,a negative number that is the bitwise complement of the index of the next element 

    that is larger than item or,if there is no larger element,the bitwise complement of 

    System.Collections.Generic.List.

  

  BinarySearch(self: List[T],item: T) -> int

  

   Searches the entire sorted System.Collections.Generic.List for an element using the default 

    comparer and returns the zero-based index of the element.

  

  

   item: The object to locate. The value can be null for reference types.

   Returns: The zero-based index of item in the sorted System.Collections.Generic.List,if item is found; 

    otherwise,a negative number that is the bitwise complement of the index of the next element 

    that is larger than item or,if there is no larger element,the bitwise complement of 

    System.Collections.Generic.List.

  

  BinarySearch(self: List[T],index: int,count: int,item: T,comparer: IComparer[T]) -> int

  

   Searches a range of elements in the sorted System.Collections.Generic.List for an element using 

    the specified comparer and returns the zero-based index of the element.

  

  

   index: The zero-based starting index of the range to search.

   count: The length of the range to search.

   item: The object to locate. The value can be null for reference types.

   comparer: The System.Collections.Generic.IComparer implementation to use when comparing elements,or null 

    to use the default comparer System.Collections.Generic.Comparer.

  

   Returns: The zero-based index of item in the sorted System.Collections.Generic.List,if item is found; 

    otherwise,a negative number that is the bitwise complement of the index of the next element 

    that is larger than item or,if there is no larger element,the bitwise complement of 

    System.Collections.Generic.List.
  """
  pass
 def Clear(self):
  """
  Clear(self: List[T])

   Removes all elements from the System.Collections.Generic.List.
  """
  pass
 def Contains(self,item):
  """
  Contains(self: List[T],item: T) -> bool

  

   Determines whether an element is in the System.Collections.Generic.List.

  

   item: The object to locate in the System.Collections.Generic.List. The value can be null for reference 

    types.

  

   Returns: true if item is found in the System.Collections.Generic.List; otherwise,false.
  """
  pass
 def ConvertAll(self,converter):
  """ ConvertAll[TOutput](self: List[T],converter: Converter[T,TOutput]) -> List[TOutput] """
  pass
 def CopyTo(self,*__args):
  """ CopyTo(self: List[T],index: int,array: Array[T],arrayIndex: int,count: int)CopyTo(self: List[T],array: Array[T],arrayIndex: int)CopyTo(self: List[T],array: Array[T]) """
  pass
 def Exists(self,match):
  """
  Exists(self: List[T],match: Predicate[T]) -> bool

  

   Determines whether the System.Collections.Generic.List contains elements that match the 

    conditions defined by the specified predicate.

  

  

   match: The System.Predicate delegate that defines the conditions of the elements to search for.

   Returns: true if the System.Collections.Generic.List contains one or more elements that match the 

    conditions defined by the specified predicate; otherwise,false.
  """
  pass
 def Find(self,match):
  """
  Find(self: List[T],match: Predicate[T]) -> T

  

   Searches for an element that matches the conditions defined by the specified predicate,and 

    returns the first occurrence within the entire System.Collections.Generic.List.

  

  

   match: The System.Predicate delegate that defines the conditions of the element to search for.

   Returns: The first element that matches the conditions defined by the specified predicate,if found; 

    otherwise,the default value for type T.
  """
  pass
 def FindAll(self,match):
  """
  FindAll(self: List[T],match: Predicate[T]) -> List[T]

  

   Retrieves all the elements that match the conditions defined by the specified predicate.

  

   match: The System.Predicate delegate that defines the conditions of the elements to search for.

   Returns: A System.Collections.Generic.List containing all the elements that match the conditions defined 

    by the specified predicate,if found; otherwise,an empty System.Collections.Generic.List.
  """
  pass
 def FindIndex(self,*__args):
  """
  FindIndex(self: List[T],startIndex: int,match: Predicate[T]) -> int

  

   Searches for an element that matches the conditions defined by the specified predicate,and 

    returns the zero-based index of the first occurrence within the range of elements in the 

    System.Collections.Generic.List that extends from the specified index to the last element.

  

  

   startIndex: The zero-based starting index of the search.

   match: The System.Predicate delegate that defines the conditions of the element to search for.

   Returns: The zero-based index of the first occurrence of an element that matches the conditions defined 

    

  FindIndex(self: List[T],startIndex: int,count: int,match: Predicate[T]) -> int

  

   Searches for an element that matches the conditions defined by the specified predicate,and 

    returns the zero-based index of the first occurrence within the range of elements in the 

    System.Collections.Generic.List that starts at the specified index and contains the specified 

    number of elements.

  

  

   startIndex: The zero-based starting index of the search.

   count: The number of elements in the section to search.

   match: The System.Predicate delegate that defines the conditions of the element to search for.

   Returns: The zero-based index of the first occurrence of an element that matches the conditions defined 

    

  FindIndex(self: List[T],match: Predicate[T]) -> int

  

   Searches for an element that matches the conditions defined by the specified predicate,and 

    returns the zero-based index of the first occurrence within the entire 

    System.Collections.Generic.List.

  

  

   match: The System.Predicate delegate that defines the conditions of the element to search for.

   Returns: The zero-based index of the first occurrence of an element that matches the conditions defined 

    """
  pass
 def FindLast(self,match):
  """
  FindLast(self: List[T],match: Predicate[T]) -> T

  

   Searches for an element that matches the conditions defined by the specified predicate,and 

    returns the last occurrence within the entire System.Collections.Generic.List.

  

  

   match: The System.Predicate delegate that defines the conditions of the element to search for.

   Returns: The last element that matches the conditions defined by the specified predicate,if found; 

    otherwise,the default value for type T.
  """
  pass
 def FindLastIndex(self,*__args):
  """
  FindLastIndex(self: List[T],startIndex: int,count: int,match: Predicate[T]) -> int

  

   Searches for an element that matches the conditions defined by the specified predicate,and 

    returns the zero-based index of the last occurrence within the range of elements in the 

    System.Collections.Generic.List that contains the specified number of elements and ends at the 

    specified index.

  

  

   startIndex: The zero-based starting index of the backward search.

   count: The number of elements in the section to search.

   match: The System.Predicate delegate that defines the conditions of the element to search for.

   Returns: The zero-based index of the last occurrence of an element that matches the conditions defined by 

    

  FindLastIndex(self: List[T],startIndex: int,match: Predicate[T]) -> int

  

   Searches for an element that matches the conditions defined by the specified predicate,and 

    returns the zero-based index of the last occurrence within the range of elements in the 

    System.Collections.Generic.List that extends from the first element to the specified index.

  

  

   startIndex: The zero-based starting index of the backward search.

   match: The System.Predicate delegate that defines the conditions of the element to search for.

   Returns: The zero-based index of the last occurrence of an element that matches the conditions defined by 

    

  FindLastIndex(self: List[T],match: Predicate[T]) -> int

  

   Searches for an element that matches the conditions defined by the specified predicate,and 

    returns the zero-based index of the last occurrence within the entire 

    System.Collections.Generic.List.

  

  

   match: The System.Predicate delegate that defines the conditions of the element to search for.

   Returns: The zero-based index of the last occurrence of an element that matches the conditions defined by 

    """
  pass
 def ForEach(self,action):
  """
  ForEach(self: List[T],action: Action[T])

   Performs the specified action on each element of the System.Collections.Generic.List.

  

   action: The System.Action delegate to perform on each element of the System.Collections.Generic.List.
  """
  pass
 def GetEnumerator(self):
  """
  GetEnumerator(self: List[T]) -> Enumerator

  

   Returns an enumerator that iterates through the System.Collections.Generic.List.

   Returns: A System.Collections.Generic.List for the System.Collections.Generic.List.
  """
  pass
 def GetRange(self,index,count):
  """
  GetRange(self: List[T],index: int,count: int) -> List[T]

  

   Creates a shallow copy of a range of elements in the source System.Collections.Generic.List.

  

   index: The zero-based System.Collections.Generic.List index at which the range starts.

   count: The number of elements in the range.

   Returns: A shallow copy of a range of elements in the source System.Collections.Generic.List.
  """
  pass
 def IndexOf(self,item,index=None,count=None):
  """
  IndexOf(self: List[T],item: T,index: int,count: int) -> int

  

   Searches for the specified object and returns the zero-based index of the first occurrence 

    within the range of elements in the System.Collections.Generic.List that starts at the specified 

    index and contains the specified number of elements.

  

  

   item: The object to locate in the System.Collections.Generic.List. The value can be null for reference 

    types.

  

   index: The zero-based starting index of the search. 0 (zero) is valid in an empty list.

   count: The number of elements in the section to search.

   Returns: The zero-based index of the first occurrence of item within the range of elements in the 

    System.Collections.Generic.List that starts at index and contains count number of elements,if 

    

  IndexOf(self: List[T],item: T,index: int) -> int

  

   Searches for the specified object and returns the zero-based index of the first occurrence 

    within the range of elements in the System.Collections.Generic.List that extends from the 

    specified index to the last element.

  

  

   item: The object to locate in the System.Collections.Generic.List. The value can be null for reference 

    types.

  

   index: The zero-based starting index of the search. 0 (zero) is valid in an empty list.

   Returns: The zero-based index of the first occurrence of item within the range of elements in the 

    System.Collections.Generic.List that extends from index to the last element,if found; 

    

  IndexOf(self: List[T],item: T) -> int

  

   Searches for the specified object and returns the zero-based index of the first occurrence 

    within the entire System.Collections.Generic.List.

  

  

   item: The object to locate in the System.Collections.Generic.List. The value can be null for reference 

    types.

  

   Returns: The zero-based index of the first occurrence of item within the entire 

    """
  pass
 def Insert(self,index,item):
  """
  Insert(self: List[T],index: int,item: T)

   Inserts an element into the System.Collections.Generic.List at the specified index.

  

   index: The zero-based index at which item should be inserted.

   item: The object to insert. The value can be null for reference types.
  """
  pass
 def InsertRange(self,index,collection):
  """
  InsertRange(self: List[T],index: int,collection: IEnumerable[T])

   Inserts the elements of a collection into the System.Collections.Generic.List at the specified 

    index.

  

  

   index: The zero-based index at which the new elements should be inserted.

   collection: The collection whose elements should be inserted into the System.Collections.Generic.List. The 

    collection itself cannot be null,but it can contain elements that are null,if type T is a 

    reference type.
  """
  pass
 def LastIndexOf(self,item,index=None,count=None):
  """
  LastIndexOf(self: List[T],item: T,index: int) -> int

  

   Searches for the specified object and returns the zero-based index of the last occurrence within 

    the range of elements in the System.Collections.Generic.List that extends from the first element 

    to the specified index.

  

  

   item: The object to locate in the System.Collections.Generic.List. The value can be null for reference 

    types.

  

   index: The zero-based starting index of the backward search.

   Returns: The zero-based index of the last occurrence of item within the range of elements in the 

    System.Collections.Generic.List that extends from the first element to index,if found; 

    

  LastIndexOf(self: List[T],item: T) -> int

  

   Searches for the specified object and returns the zero-based index of the last occurrence within 

    the entire System.Collections.Generic.List.

  

  

   item: The object to locate in the System.Collections.Generic.List. The value can be null for reference 

    types.

  

   Returns: The zero-based index of the last occurrence of item within the entire the 

    

  LastIndexOf(self: List[T],item: T,index: int,count: int) -> int

  

   Searches for the specified object and returns the zero-based index of the last occurrence within 

    the range of elements in the System.Collections.Generic.List that contains the specified number 

    of elements and ends at the specified index.

  

  

   item: The object to locate in the System.Collections.Generic.List. The value can be null for reference 

    types.

  

   index: The zero-based starting index of the backward search.

   count: The number of elements in the section to search.

   Returns: The zero-based index of the last occurrence of item within the range of elements in the 

    System.Collections.Generic.List that contains count number of elements and ends at index,if 

    """
  pass
 def Remove(self,item):
  """
  Remove(self: List[T],item: T) -> bool

  

   Removes the first occurrence of a specific object from the System.Collections.Generic.List.

  

   item: The object to remove from the System.Collections.Generic.List. The value can be null for 

    reference types.

  

   Returns: true if item is successfully removed; otherwise,false.  This method also returns false if item 

    was not found in the System.Collections.Generic.List.
  """
  pass
 def RemoveAll(self,match):
  """
  RemoveAll(self: List[T],match: Predicate[T]) -> int

  

   Removes all the elements that match the conditions defined by the specified predicate.

  

   match: The System.Predicate delegate that defines the conditions of the elements to remove.

   Returns: The number of elements removed from the System.Collections.Generic.List .
  """
  pass
 def RemoveAt(self,index):
  """
  RemoveAt(self: List[T],index: int)

   Removes the element at the specified index of the System.Collections.Generic.List.

  

   index: The zero-based index of the element to remove.
  """
  pass
 def RemoveRange(self,index,count):
  """
  RemoveRange(self: List[T],index: int,count: int)

   Removes a range of elements from the System.Collections.Generic.List.

  

   index: The zero-based starting index of the range of elements to remove.

   count: The number of elements to remove.
  """
  pass
 def Reverse(self,index=None,count=None):
  """
  Reverse(self: List[T],index: int,count: int)

   Reverses the order of the elements in the specified range.

  

   index: The zero-based starting index of the range to reverse.

   count: The number of elements in the range to reverse.

  Reverse(self: List[T])

   Reverses the order of the elements in the entire System.Collections.Generic.List.
  """
  pass
 def Sort(self,*__args):
  """
  Sort(self: List[T],index: int,count: int,comparer: IComparer[T])

   Sorts the elements in a range of elements in System.Collections.Generic.List using the specified 

    comparer.

  

  

   index: The zero-based starting index of the range to sort.

   count: The length of the range to sort.

   comparer: The System.Collections.Generic.IComparer implementation to use when comparing elements,or null 

    to use the default comparer System.Collections.Generic.Comparer.

  

  Sort(self: List[T],comparison: Comparison[T])

   Sorts the elements in the entire System.Collections.Generic.List using the specified 

    System.Comparison.

  

  

   comparison: The System.Comparison to use when comparing elements.

  Sort(self: List[T])

   Sorts the elements in the entire System.Collections.Generic.List using the default comparer.

  Sort(self: List[T],comparer: IComparer[T])

   Sorts the elements in the entire System.Collections.Generic.List using the specified comparer.

  

   comparer: The System.Collections.Generic.IComparer implementation to use when comparing elements,or null 

    to use the default comparer System.Collections.Generic.Comparer.
  """
  pass
 def ToArray(self):
  """
  ToArray(self: List[T]) -> Array[T]

  

   Copies the elements of the System.Collections.Generic.List to a new array.

   Returns: An array containing copies of the elements of the System.Collections.Generic.List.
  """
  pass
 def TrimExcess(self):
  """
  TrimExcess(self: List[T])

   Sets the capacity to the actual number of elements in the System.Collections.Generic.List,if 

    that number is less than a threshold value.
  """
  pass
 def TrueForAll(self,match):
  """
  TrueForAll(self: List[T],match: Predicate[T]) -> bool

  

   Determines whether every element in the System.Collections.Generic.List matches the conditions 

    defined by the specified predicate.

  

  

   match: The System.Predicate delegate that defines the conditions to check against the elements.

   Returns: true if every element in the System.Collections.Generic.List matches the conditions defined by 

    the specified predicate; otherwise,false. If the list has no elements,the return value is 

    true.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __contains__(self,*args):
  """
  __contains__(self: ICollection[T],item: T) -> bool

  

   Determines whether the System.Collections.Generic.ICollection contains a specific value.

  

   item: The object to locate in the System.Collections.Generic.ICollection.

   Returns: true if item is found in the System.Collections.Generic.ICollection; otherwise,false.

  __contains__(self: IList,value: object) -> bool

  

   Determines whether the System.Collections.IList contains a specific value.

  

   value: The object to locate in the System.Collections.IList.

   Returns: true if the System.Object is found in the System.Collections.IList; otherwise,false.
  """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __len__(self,*args):
  """ x.__len__() <==> len(x) """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type)

  __new__(cls: type,capacity: int)

  __new__(cls: type,collection: IEnumerable[T])
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __repr__(self,*args):
  """
  __repr__(self: List[T]) -> str

  __repr__(self: List[T]) -> str
  """
  pass
 def __setitem__(self,*args):
  """ x.__setitem__(i,y) <==> x[i]= """
  pass
 Capacity=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the total number of elements the internal data structure can hold without resizing.



Get: Capacity(self: List[T]) -> int



Set: Capacity(self: List[T])=value

"""

 Count=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the number of elements actually contained in the System.Collections.Generic.List.



Get: Count(self: List[T]) -> int



"""


 Enumerator=None


class Queue(object,IEnumerable[T],IEnumerable,ICollection,IReadOnlyCollection[T]):
 """
 Queue[T]()

 Queue[T](capacity: int)

 Queue[T](collection: IEnumerable[T])
 """
 def Clear(self):
  """
  Clear(self: Queue[T])

   Removes all objects from the System.Collections.Generic.Queue.
  """
  pass
 def Contains(self,item):
  """
  Contains(self: Queue[T],item: T) -> bool

  

   Determines whether an element is in the System.Collections.Generic.Queue.

  

   item: The object to locate in the System.Collections.Generic.Queue. The value can be null for 

    reference types.

  

   Returns: true if item is found in the System.Collections.Generic.Queue; otherwise,false.
  """
  pass
 def CopyTo(self,array,arrayIndex):
  """ CopyTo(self: Queue[T],array: Array[T],arrayIndex: int) """
  pass
 def Dequeue(self):
  """
  Dequeue(self: Queue[T]) -> T

  

   Removes and returns the object at the beginning of the System.Collections.Generic.Queue.

   Returns: The object that is removed from the beginning of the System.Collections.Generic.Queue.
  """
  pass
 def Enqueue(self,item):
  """
  Enqueue(self: Queue[T],item: T)

   Adds an object to the end of the System.Collections.Generic.Queue.

  

   item: The object to add to the System.Collections.Generic.Queue. The value can be null for reference 

    types.
  """
  pass
 def GetEnumerator(self):
  """
  GetEnumerator(self: Queue[T]) -> Enumerator

  

   Returns an enumerator that iterates through the System.Collections.Generic.Queue.

   Returns: An System.Collections.Generic.Queue for the System.Collections.Generic.Queue.
  """
  pass
 def Peek(self):
  """
  Peek(self: Queue[T]) -> T

  

   Returns the object at the beginning of the System.Collections.Generic.Queue without removing it.

   Returns: The object at the beginning of the System.Collections.Generic.Queue.
  """
  pass
 def ToArray(self):
  """
  ToArray(self: Queue[T]) -> Array[T]

  

   Copies the System.Collections.Generic.Queue elements to a new array.

   Returns: A new array containing elements copied from the System.Collections.Generic.Queue.
  """
  pass
 def TrimExcess(self):
  """
  TrimExcess(self: Queue[T])

   Sets the capacity to the actual number of elements in the System.Collections.Generic.Queue,if 

    that number is less than 90 percent of current capacity.
  """
  pass
 def __contains__(self,*args):
  """ __contains__[T](enumerable: IEnumerable[T],value: T) -> bool """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __len__(self,*args):
  """ x.__len__() <==> len(x) """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type)

  __new__(cls: type,capacity: int)

  __new__(cls: type,collection: IEnumerable[T])
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 Count=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the number of elements contained in the System.Collections.Generic.Queue.



Get: Count(self: Queue[T]) -> int



"""


 Enumerator=None


class SortedDictionary(object,IDictionary[TKey,TValue],ICollection[KeyValuePair[TKey,TValue]],IEnumerable[KeyValuePair[TKey,TValue]],IEnumerable,IDictionary,ICollection,IReadOnlyDictionary[TKey,TValue],IReadOnlyCollection[KeyValuePair[TKey,TValue]]):
 """
 SortedDictionary[TKey,TValue]()

 SortedDictionary[TKey,TValue](comparer: IComparer[TKey])

 SortedDictionary[TKey,TValue](dictionary: IDictionary[TKey,TValue])

 SortedDictionary[TKey,TValue](dictionary: IDictionary[TKey,TValue],comparer: IComparer[TKey])
 """
 def Add(self,key,value):
  """
  Add(self: SortedDictionary[TKey,TValue],key: TKey,value: TValue)

   Adds an element with the specified key and value into the 

    System.Collections.Generic.SortedDictionary.

  

  

   key: The key of the element to add.

   value: The value of the element to add. The value can be null for reference types.
  """
  pass
 def Clear(self):
  """
  Clear(self: SortedDictionary[TKey,TValue])

   Removes all elements from the System.Collections.Generic.SortedDictionary.
  """
  pass
 def ContainsKey(self,key):
  """
  ContainsKey(self: SortedDictionary[TKey,TValue],key: TKey) -> bool

  

   Determines whether the System.Collections.Generic.SortedDictionary contains an element with the 

    specified key.

  

  

   key: The key to locate in the System.Collections.Generic.SortedDictionary.

   Returns: true if the System.Collections.Generic.SortedDictionary contains an element with the specified 

    key; otherwise,false.
  """
  pass
 def ContainsValue(self,value):
  """
  ContainsValue(self: SortedDictionary[TKey,TValue],value: TValue) -> bool

  

   Determines whether the System.Collections.Generic.SortedDictionary contains an element with the 

    specified value.

  

  

   value: The value to locate in the System.Collections.Generic.SortedDictionary. The value can be null 

    for reference types.

  

   Returns: true if the System.Collections.Generic.SortedDictionary contains an element with the specified 

    value; otherwise,false.
  """
  pass
 def CopyTo(self,array,index):
  """ CopyTo(self: SortedDictionary[TKey,TValue],array: Array[KeyValuePair[TKey,TValue]],index: int) """
  pass
 def GetEnumerator(self):
  """
  GetEnumerator(self: SortedDictionary[TKey,TValue]) -> Enumerator

  

   Returns an enumerator that iterates through the System.Collections.Generic.SortedDictionary.

   Returns: A System.Collections.Generic.SortedDictionary for the 

    System.Collections.Generic.SortedDictionary.
  """
  pass
 def Remove(self,key):
  """
  Remove(self: SortedDictionary[TKey,TValue],key: TKey) -> bool

  

   Removes the element with the specified key from the System.Collections.Generic.SortedDictionary.

  

   key: The key of the element to remove.

   Returns: true if the element is successfully removed; otherwise,false.  This method also returns false 

    if key is not found in the System.Collections.Generic.SortedDictionary.
  """
  pass
 def TryGetValue(self,key,value):
  """ TryGetValue(self: SortedDictionary[TKey,TValue],key: TKey) -> (bool,TValue) """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __contains__(self,*args):
  """
  __contains__(self: IDictionary[TKey,TValue],key: TKey) -> bool

  

   Determines whether the System.Collections.Generic.IDictionary contains an element with the 

    specified key.

  

  

   key: The key to locate in the System.Collections.Generic.IDictionary.

   Returns: true if the System.Collections.Generic.IDictionary contains an element with the key; otherwise,

    false.

  

  __contains__(self: IDictionary,key: object) -> bool

  

   Determines whether the System.Collections.IDictionary object contains an element with the 

    specified key.

  

  

   key: The key to locate in the System.Collections.IDictionary object.

   Returns: true if the System.Collections.IDictionary contains an element with the key; otherwise,false.
  """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __len__(self,*args):
  """ x.__len__() <==> len(x) """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type)

  __new__(cls: type,dictionary: IDictionary[TKey,TValue])

  __new__(cls: type,dictionary: IDictionary[TKey,TValue],comparer: IComparer[TKey])

  __new__(cls: type,comparer: IComparer[TKey])
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 def __setitem__(self,*args):
  """ x.__setitem__(i,y) <==> x[i]= """
  pass
 Comparer=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Collections.Generic.IComparer used to order the elements of the System.Collections.Generic.SortedDictionary.



Get: Comparer(self: SortedDictionary[TKey,TValue]) -> IComparer[TKey]



"""

 Count=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the number of key/value pairs contained in the System.Collections.Generic.SortedDictionary.



Get: Count(self: SortedDictionary[TKey,TValue]) -> int



"""

 Keys=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a collection containing the keys in the System.Collections.Generic.SortedDictionary.



Get: Keys(self: SortedDictionary[TKey,TValue]) -> KeyCollection



"""

 Values=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a collection containing the values in the System.Collections.Generic.SortedDictionary.



Get: Values(self: SortedDictionary[TKey,TValue]) -> ValueCollection



"""


 Enumerator=None
 KeyCollection=None
 ValueCollection=None


class SortedList(object,IDictionary[TKey,TValue],ICollection[KeyValuePair[TKey,TValue]],IEnumerable[KeyValuePair[TKey,TValue]],IEnumerable,IDictionary,ICollection,IReadOnlyDictionary[TKey,TValue],IReadOnlyCollection[KeyValuePair[TKey,TValue]]):
 """
 SortedList[TKey,TValue]()

 SortedList[TKey,TValue](capacity: int)

 SortedList[TKey,TValue](comparer: IComparer[TKey])

 SortedList[TKey,TValue](capacity: int,comparer: IComparer[TKey])

 SortedList[TKey,TValue](dictionary: IDictionary[TKey,TValue])

 SortedList[TKey,TValue](dictionary: IDictionary[TKey,TValue],comparer: IComparer[TKey])
 """
 def Add(self,key,value):
  """
  Add(self: SortedList[TKey,TValue],key: TKey,value: TValue)

   Adds an element with the specified key and value into the System.Collections.Generic.SortedList.

  

   key: The key of the element to add.

   value: The value of the element to add. The value can be null for reference types.
  """
  pass
 def Clear(self):
  """
  Clear(self: SortedList[TKey,TValue])

   Removes all elements from the System.Collections.Generic.SortedList.
  """
  pass
 def ContainsKey(self,key):
  """
  ContainsKey(self: SortedList[TKey,TValue],key: TKey) -> bool

  

   Determines whether the System.Collections.Generic.SortedList contains a specific key.

  

   key: The key to locate in the System.Collections.Generic.SortedList.

   Returns: true if the System.Collections.Generic.SortedList contains an element with the specified key; 

    otherwise,false.
  """
  pass
 def ContainsValue(self,value):
  """
  ContainsValue(self: SortedList[TKey,TValue],value: TValue) -> bool

  

   Determines whether the System.Collections.Generic.SortedList contains a specific value.

  

   value: The value to locate in the System.Collections.Generic.SortedList. The value can be null for 

    reference types.

  

   Returns: true if the System.Collections.Generic.SortedList contains an element with the specified value; 

    otherwise,false.
  """
  pass
 def GetEnumerator(self):
  """
  GetEnumerator(self: SortedList[TKey,TValue]) -> IEnumerator[KeyValuePair[TKey,TValue]]

  

   Returns an enumerator that iterates through the System.Collections.Generic.SortedList.

   Returns: An System.Collections.Generic.IEnumerator of type System.Collections.Generic.KeyValuePair for 

    the System.Collections.Generic.SortedList.
  """
  pass
 def IndexOfKey(self,key):
  """
  IndexOfKey(self: SortedList[TKey,TValue],key: TKey) -> int

  

   Searches for the specified key and returns the zero-based index within the entire 

    System.Collections.Generic.SortedList.

  

  

   key: The key to locate in the System.Collections.Generic.SortedList.

   Returns: The zero-based index of key within the entire System.Collections.Generic.SortedList,if found; 

    otherwise,-1.
  """
  pass
 def IndexOfValue(self,value):
  """
  IndexOfValue(self: SortedList[TKey,TValue],value: TValue) -> int

  

   Searches for the specified value and returns the zero-based index of the first occurrence within 

    the entire System.Collections.Generic.SortedList.

  

  

   value: The value to locate in the System.Collections.Generic.SortedList.  The value can be null for 

    reference types.

  

   Returns: The zero-based index of the first occurrence of value within the entire 

    System.Collections.Generic.SortedList,if found; otherwise,-1.
  """
  pass
 def Remove(self,key):
  """
  Remove(self: SortedList[TKey,TValue],key: TKey) -> bool

  

   Removes the element with the specified key from the System.Collections.Generic.SortedList.

  

   key: The key of the element to remove.

   Returns: true if the element is successfully removed; otherwise,false.  This method also returns false 

    if key was not found in the original System.Collections.Generic.SortedList.
  """
  pass
 def RemoveAt(self,index):
  """
  RemoveAt(self: SortedList[TKey,TValue],index: int)

   Removes the element at the specified index of the System.Collections.Generic.SortedList.

  

   index: The zero-based index of the element to remove.
  """
  pass
 def TrimExcess(self):
  """
  TrimExcess(self: SortedList[TKey,TValue])

   Sets the capacity to the actual number of elements in the System.Collections.Generic.SortedList,

    if that number is less than 90 percent of current capacity.
  """
  pass
 def TryGetValue(self,key,value):
  """ TryGetValue(self: SortedList[TKey,TValue],key: TKey) -> (bool,TValue) """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __contains__(self,*args):
  """
  __contains__(self: IDictionary[TKey,TValue],key: TKey) -> bool

  

   Determines whether the System.Collections.Generic.IDictionary contains an element with the 

    specified key.

  

  

   key: The key to locate in the System.Collections.Generic.IDictionary.

   Returns: true if the System.Collections.Generic.IDictionary contains an element with the key; otherwise,

    false.

  

  __contains__(self: IDictionary,key: object) -> bool

  

   Determines whether the System.Collections.IDictionary object contains an element with the 

    specified key.

  

  

   key: The key to locate in the System.Collections.IDictionary object.

   Returns: true if the System.Collections.IDictionary contains an element with the key; otherwise,false.
  """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __len__(self,*args):
  """ x.__len__() <==> len(x) """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type)

  __new__(cls: type,capacity: int)

  __new__(cls: type,comparer: IComparer[TKey])

  __new__(cls: type,capacity: int,comparer: IComparer[TKey])

  __new__(cls: type,dictionary: IDictionary[TKey,TValue])

  __new__(cls: type,dictionary: IDictionary[TKey,TValue],comparer: IComparer[TKey])
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 def __setitem__(self,*args):
  """ x.__setitem__(i,y) <==> x[i]= """
  pass
 Capacity=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the number of elements that the System.Collections.Generic.SortedList can contain.



Get: Capacity(self: SortedList[TKey,TValue]) -> int



Set: Capacity(self: SortedList[TKey,TValue])=value

"""

 Comparer=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Collections.Generic.IComparer for the sorted list.



Get: Comparer(self: SortedList[TKey,TValue]) -> IComparer[TKey]



"""

 Count=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the number of key/value pairs contained in the System.Collections.Generic.SortedList.



Get: Count(self: SortedList[TKey,TValue]) -> int



"""

 Keys=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a collection containing the keys in the System.Collections.Generic.SortedList.



Get: Keys(self: SortedList[TKey,TValue]) -> IList[TKey]



"""

 Values=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a collection containing the values in the System.Collections.Generic.SortedList.



Get: Values(self: SortedList[TKey,TValue]) -> IList[TValue]



"""



class SortedSet(object,ISet[T],ICollection[T],IEnumerable[T],IEnumerable,ICollection,ISerializable,IDeserializationCallback,IReadOnlyCollection[T]):
 """
 SortedSet[T]()

 SortedSet[T](collection: IEnumerable[T])

 SortedSet[T](collection: IEnumerable[T],comparer: IComparer[T])

 SortedSet[T](comparer: IComparer[T])
 """
 def Add(self,item):
  """
  Add(self: SortedSet[T],item: T) -> bool

  

   Adds an element to the set and returns a value that indicates if it was successfully added.

  

   item: The element to add to the set.

   Returns: true if item is added to the set; otherwise,false.
  """
  pass
 def Clear(self):
  """
  Clear(self: SortedSet[T])

   Removes all elements from the set.
  """
  pass
 def Contains(self,item):
  """
  Contains(self: SortedSet[T],item: T) -> bool

  

   Determines whether the set contains a specific element.

  

   item: The element to locate in the set.

   Returns: true if the set contains item; otherwise,false.
  """
  pass
 def CopyTo(self,array,index=None,count=None):
  """ CopyTo(self: SortedSet[T],array: Array[T],index: int,count: int)CopyTo(self: SortedSet[T],array: Array[T],index: int)CopyTo(self: SortedSet[T],array: Array[T]) """
  pass
 @staticmethod
 def CreateSetComparer(memberEqualityComparer=None):
  """
  CreateSetComparer(memberEqualityComparer: IEqualityComparer[T]) -> IEqualityComparer[SortedSet[T]]

  

   Returns an System.Collections.IEqualityComparer object,according to a specified comparer,that 

    can be used to create a collection that contains individual sets.

  

  

   memberEqualityComparer: The comparer to use for creating the returned comparer.

   Returns: A comparer for creating a collection of sets.

  CreateSetComparer() -> IEqualityComparer[SortedSet[T]]

  

   Returns an System.Collections.IEqualityComparer object that can be used to create a collection 

    that contains individual sets.

  

   Returns: A comparer for creating a collection of sets.
  """
  pass
 def ExceptWith(self,other):
  """
  ExceptWith(self: SortedSet[T],other: IEnumerable[T])

   Removes all elements that are in a specified collection from the current 

    System.Collections.Generic.SortedSet object.

  

  

   other: The collection of items to remove from the System.Collections.Generic.SortedSet object.
  """
  pass
 def GetEnumerator(self):
  """
  GetEnumerator(self: SortedSet[T]) -> Enumerator

  

   Returns an enumerator that iterates through the System.Collections.Generic.SortedSet.

   Returns: An enumerator that iterates through the System.Collections.Generic.SortedSet.
  """
  pass
 def GetObjectData(self,*args):
  """
  GetObjectData(self: SortedSet[T],info: SerializationInfo,context: StreamingContext)

   Implements the System.Runtime.Serialization.ISerializable interface and returns the data that 

    you must have to serialize a System.Collections.Generic.SortedSet object.

  

  

   info: A System.Runtime.Serialization.SerializationInfo object that contains the information that is 

    required to serialize the System.Collections.Generic.SortedSet object.

  

   context: A System.Runtime.Serialization.StreamingContext structure that contains the source and 

    destination of the serialized stream associated with the System.Collections.Generic.SortedSet 

    object.
  """
  pass
 def GetViewBetween(self,lowerValue,upperValue):
  """
  GetViewBetween(self: SortedSet[T],lowerValue: T,upperValue: T) -> SortedSet[T]

  

   Returns a view of a subset in a System.Collections.Generic.SortedSet.

  

   lowerValue: The lowest desired value in the view.

   upperValue: The highest desired value in the view.

   Returns: A subset view that contains only the values in the specified range.
  """
  pass
 def IntersectWith(self,other):
  """
  IntersectWith(self: SortedSet[T],other: IEnumerable[T])

   Modifies the current System.Collections.Generic.SortedSet object so that it contains only 

    elements that are also in a specified collection.

  

  

   other: The collection to compare to the current System.Collections.Generic.SortedSet object.
  """
  pass
 def IsProperSubsetOf(self,other):
  """
  IsProperSubsetOf(self: SortedSet[T],other: IEnumerable[T]) -> bool

  

   Determines whether a System.Collections.Generic.SortedSet object is a proper subset of the 

    specified collection.

  

  

   other: The collection to compare to the current System.Collections.Generic.SortedSet object.

   Returns: true if the System.Collections.Generic.SortedSet object is a proper subset of other; otherwise,

    false.
  """
  pass
 def IsProperSupersetOf(self,other):
  """
  IsProperSupersetOf(self: SortedSet[T],other: IEnumerable[T]) -> bool

  

   Determines whether a System.Collections.Generic.SortedSet object is a proper superset of the 

    specified collection.

  

  

   other: The collection to compare to the current System.Collections.Generic.SortedSet object.

   Returns: true if the System.Collections.Generic.SortedSet object is a proper superset of other; 

    otherwise,false.
  """
  pass
 def IsSubsetOf(self,other):
  """
  IsSubsetOf(self: SortedSet[T],other: IEnumerable[T]) -> bool

  

   Determines whether a System.Collections.Generic.SortedSet object is a subset of the specified 

    collection.

  

  

   other: The collection to compare to the current System.Collections.Generic.SortedSet object.

   Returns: true if the current System.Collections.Generic.SortedSet object is a subset of other; otherwise,

    false.
  """
  pass
 def IsSupersetOf(self,other):
  """
  IsSupersetOf(self: SortedSet[T],other: IEnumerable[T]) -> bool

  

   Determines whether a System.Collections.Generic.SortedSet object is a superset of the specified 

    collection.

  

  

   other: The collection to compare to the current System.Collections.Generic.SortedSet object.

   Returns: true if the System.Collections.Generic.SortedSet object is a superset of other; otherwise,false.
  """
  pass
 def OnDeserialization(self,*args):
  """
  OnDeserialization(self: SortedSet[T],sender: object)

   Implements the System.Runtime.Serialization.ISerializable interface,and raises the 

    deserialization event when the deserialization is completed.

  

  

   sender: The source of the deserialization event.
  """
  pass
 def Overlaps(self,other):
  """
  Overlaps(self: SortedSet[T],other: IEnumerable[T]) -> bool

  

   Determines whether the current System.Collections.Generic.SortedSet object and a specified 

    collection share common elements.

  

  

   other: The collection to compare to the current System.Collections.Generic.SortedSet object.

   Returns: true if the System.Collections.Generic.SortedSet object and other share at least one common 

    element; otherwise,false.
  """
  pass
 def Remove(self,item):
  """
  Remove(self: SortedSet[T],item: T) -> bool

  

   Removes a specified item from the System.Collections.Generic.SortedSet.

  

   item: The element to remove.

   Returns: true if the element is found and successfully removed; otherwise,false.
  """
  pass
 def RemoveWhere(self,match):
  """
  RemoveWhere(self: SortedSet[T],match: Predicate[T]) -> int

  

   Removes all elements that match the conditions defined by the specified predicate from a 

    System.Collections.Generic.SortedSet.

  

  

   match: The delegate that defines the conditions of the elements to remove.

   Returns: The number of elements that were removed from the System.Collections.Generic.SortedSet 

    collection..
  """
  pass
 def Reverse(self):
  """
  Reverse(self: SortedSet[T]) -> IEnumerable[T]

  

   Returns an System.Collections.Generic.IEnumerable that iterates over the 

    System.Collections.Generic.SortedSet in reverse order.

  

   Returns: An enumerator that iterates over the System.Collections.Generic.SortedSet in reverse order.
  """
  pass
 def SetEquals(self,other):
  """
  SetEquals(self: SortedSet[T],other: IEnumerable[T]) -> bool

  

   Determines whether the current System.Collections.Generic.SortedSet object and the specified 

    collection contain the same elements.

  

  

   other: The collection to compare to the current System.Collections.Generic.SortedSet object.

   Returns: true if the current System.Collections.Generic.SortedSet object is equal to other; otherwise,

    false.
  """
  pass
 def SymmetricExceptWith(self,other):
  """
  SymmetricExceptWith(self: SortedSet[T],other: IEnumerable[T])

   Modifies the current System.Collections.Generic.SortedSet object so that it contains only 

    elements that are present either in the current object or in the specified collection,but not 

    both.

  

  

   other: The collection to compare to the current System.Collections.Generic.SortedSet object.
  """
  pass
 def UnionWith(self,other):
  """
  UnionWith(self: SortedSet[T],other: IEnumerable[T])

   Modifies the current System.Collections.Generic.SortedSet object so that it contains all 

    elements that are present in both the current object and in the specified collection.

  

  

   other: The collection to compare to the current System.Collections.Generic.SortedSet object.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __contains__(self,*args):
  """
  __contains__(self: ICollection[T],item: T) -> bool

  

   Determines whether the System.Collections.Generic.ICollection contains a specific value.

  

   item: The object to locate in the System.Collections.Generic.ICollection.

   Returns: true if item is found in the System.Collections.Generic.ICollection; otherwise,false.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __len__(self,*args):
  """ x.__len__() <==> len(x) """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type)

  __new__(cls: type,comparer: IComparer[T])

  __new__(cls: type,collection: IEnumerable[T])

  __new__(cls: type,collection: IEnumerable[T],comparer: IComparer[T])

  __new__(cls: type,info: SerializationInfo,context: StreamingContext)
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 Comparer=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Collections.Generic.IEqualityComparer object that is used to determine equality for the values in the System.Collections.Generic.SortedSet.



Get: Comparer(self: SortedSet[T]) -> IComparer[T]



"""

 Count=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the number of elements in the System.Collections.Generic.SortedSet.



Get: Count(self: SortedSet[T]) -> int



"""

 Max=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the maximum value in the System.Collections.Generic.SortedSet,as defined by the comparer.



Get: Max(self: SortedSet[T]) -> T



"""

 Min=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the minimum value in the System.Collections.Generic.SortedSet,as defined by the comparer.



Get: Min(self: SortedSet[T]) -> T



"""


 Enumerator=None


class Stack(object,IEnumerable[T],IEnumerable,ICollection,IReadOnlyCollection[T]):
 """
 Stack[T]()

 Stack[T](capacity: int)

 Stack[T](collection: IEnumerable[T])
 """
 def Clear(self):
  """
  Clear(self: Stack[T])

   Removes all objects from the System.Collections.Generic.Stack.
  """
  pass
 def Contains(self,item):
  """
  Contains(self: Stack[T],item: T) -> bool

  

   Determines whether an element is in the System.Collections.Generic.Stack.

  

   item: The object to locate in the System.Collections.Generic.Stack. The value can be null for 

    reference types.

  

   Returns: true if item is found in the System.Collections.Generic.Stack; otherwise,false.
  """
  pass
 def CopyTo(self,array,arrayIndex):
  """ CopyTo(self: Stack[T],array: Array[T],arrayIndex: int) """
  pass
 def GetEnumerator(self):
  """
  GetEnumerator(self: Stack[T]) -> Enumerator

  

   Returns an enumerator for the System.Collections.Generic.Stack.

   Returns: An System.Collections.Generic.Stack for the System.Collections.Generic.Stack.
  """
  pass
 def Peek(self):
  """
  Peek(self: Stack[T]) -> T

  

   Returns the object at the top of the System.Collections.Generic.Stack without removing it.

   Returns: The object at the top of the System.Collections.Generic.Stack.
  """
  pass
 def Pop(self):
  """
  Pop(self: Stack[T]) -> T

  

   Removes and returns the object at the top of the System.Collections.Generic.Stack.

   Returns: The object removed from the top of the System.Collections.Generic.Stack.
  """
  pass
 def Push(self,item):
  """
  Push(self: Stack[T],item: T)

   Inserts an object at the top of the System.Collections.Generic.Stack.

  

   item: The object to push onto the System.Collections.Generic.Stack. The value can be null for 

    reference types.
  """
  pass
 def ToArray(self):
  """
  ToArray(self: Stack[T]) -> Array[T]

  

   Copies the System.Collections.Generic.Stack to a new array.

   Returns: A new array containing copies of the elements of the System.Collections.Generic.Stack.
  """
  pass
 def TrimExcess(self):
  """
  TrimExcess(self: Stack[T])

   Sets the capacity to the actual number of elements in the System.Collections.Generic.Stack,if 

    that number is less than 90 percent of current capacity.
  """
  pass
 def __contains__(self,*args):
  """ __contains__[T](enumerable: IEnumerable[T],value: T) -> bool """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __len__(self,*args):
  """ x.__len__() <==> len(x) """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type)

  __new__(cls: type,capacity: int)

  __new__(cls: type,collection: IEnumerable[T])
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 Count=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the number of elements contained in the System.Collections.Generic.Stack.



Get: Count(self: Stack[T]) -> int



"""


 Enumerator=None





# encoding: utf-8
# module System.Windows.Navigation calls itself Navigation
# from PresentationCore,Version=4.0.0.0,Culture=neutral,PublicKeyToken=31bf3856ad364e35
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes

class BaseUriHelper(object):
 """ Provides a method to resolve relative uniform resource identifiers (URIs) with respect to the base URI of a container,such as a System.Windows.Controls.Frame. """
 @staticmethod
 def GetBaseUri(element):
  """
  GetBaseUri(element: DependencyObject) -> Uri

  

   Gets the value of the BaseUri�attached property for a specified System.Windows.UIElement.

  

   element: The element from which the property value is read.

   Returns: The base URI of a given element.
  """
  pass
 BaseUriProperty=None
 __all__=[
  'BaseUriProperty',
  'GetBaseUri',
 ]


